@@ -159,6 +159,9 @@ TQCString demarshal( TQDataStream &stream, const TQString &type )
     } else if ( type == TQSTRINGLIST_OBJECT_NAME_STRING )
     {
         return demarshal( stream, TQVALUELIST_OBJECT_NAME_STRING "<" TQSTRING_OBJECT_NAME_STRING ">" );
+    } else if ( type == "TQStringVariantMap" )
+    {
+        return demarshal(stream, TQMAP_OBJECT_NAME_STRING "<" TQSTRING_OBJECT_NAME_STRING "," TQVARIANT_OBJECT_NAME_STRING ">");
     } else if ( type == TQCOLOR_OBJECT_NAME_STRING )
     {
         TQColor c;
@@ -339,7 +342,7 @@ void marshall( TQDataStream &arg, QCStringList args, uint &i, TQString type )
 	int tqRectKeywordLength = strlen(TQRECT_OBJECT_NAME_STRING);
 	int tqColorKeywordLength = strlen(TQCOLOR_OBJECT_NAME_STRING);
 	if ( s == "true" || s == "false" ) {
-	    arg << TQVariant( mkBool( s ), 42 );
+	    arg << TQVariant( mkBool( s ) );
 	}
 	else if ( s.left( 4 ) == "int(" ) {
 	    arg << TQVariant( s.mid(4, s.length()-5).toInt() );
