@@ -41,8 +41,6 @@
 #ifndef TQGLOBAL_H
 #define TQGLOBAL_H
 
-#define TQT_REAL_TQT 1
-
 #define TQT_VERSION_STR   "3.5.0"
 /*
    TQT_VERSION is (major << 16) + (minor << 8) + patch.
@@ -287,7 +285,7 @@
 /* ??? */
 #    define Q_BROKEN_TEMPLATE_SPECIALIZATION
 /* no template classes in TQVariant */
-#    define QT_NO_TEMPLATE_VARIANT
+#    define TQT_NO_TEMPLATE_VARIANT
 /* Wcc does not fill in functions needed by valuelists, maps, and
    valuestacks implicitly */
 #    define TQ_FULL_TEMPLATE_INSTANTIATION
@@ -295,9 +293,9 @@
 #    define TQ_FULL_TEMPLATE_INSTANTIATION_MEMCMP
 /* these are not useful to our customers */
 #    define QT_QWS_NO_SHM
-#    define QT_NO_QWS_MULTIPROCESS
-#    define QT_NO_SQL
-#    define QT_NO_QWS_CURSOR
+#    define TQT_NO_QWS_MULTIPROCESS
+#    define TQT_NO_SQL
+#    define TQT_NO_QWS_CURSOR
 #  endif
 
 #elif defined(__GNUC__)
@@ -583,7 +581,7 @@
 #elif defined(Q_OS_UNIX)
 #  if defined(TQWS)
 #    define Q_WS_QWS
-#    define QT_NO_QWS_IM
+#    define TQT_NO_QWS_IM
 #  elif defined(Q_OS_MACX)
 #    define Q_WS_MACX
 #  else
@@ -702,16 +700,6 @@ inline int tqRound( double d )
 // Size-dependent types (architechture-dependent byte order)
 //
 
-#if !defined(QT_CLEAN_NAMESPACE)
-// source compatibility with TQt 1.x
-typedef signed char		INT8;		// 8 bit signed
-typedef unsigned char		UINT8;		// 8 bit unsigned
-typedef short			INT16;		// 16 bit signed
-typedef unsigned short		UINT16;		// 16 bit unsigned
-typedef int			INT32;		// 32 bit signed
-typedef unsigned int		UINT32;		// 32 bit unsigned
-#endif
-
 typedef signed char		TQ_INT8;		// 8 bit signed
 typedef unsigned char		TQ_UINT8;	// 8 bit unsigned
 typedef short			TQ_INT16;	// 16 bit signed
@@ -760,8 +748,8 @@ class TQString;
 //
 // Feature subsetting
 //
-// Note that disabling some features will produce a libqt that is not
-// compatible with other libqt builds. Such modifications are only
+// Note that disabling some features will produce a libtqt that is not
+// compatible with other libtqt builds. Such modifications are only
 // supported on TQt/Embedded where reducing the library size is important
 // and where the application-suite is often a fixed set.
 //
@@ -790,31 +778,28 @@ class TQString;
 // prune to local config
 #include "ntqmodules.h"
 #ifndef TQT_MODULE_DIALOGS
-# define QT_NO_DIALOG
-#endif
-#ifndef TQT_MODULE_ICONVIEW
-# define QT_NO_ICONVIEW
+# define TQT_NO_DIALOG
 #endif
 #ifndef TQT_MODULE_WORKSPACE
-# define QT_NO_WORKSPACE
+# define TQT_NO_WORKSPACE
 #endif
 #ifndef TQT_MODULE_NETWORK
-#define QT_NO_NETWORK
+#define TQT_NO_NETWORK
 #endif
 #ifndef TQT_MODULE_CANVAS
-# define QT_NO_CANVAS
+# define TQT_NO_CANVAS
 #endif
 #ifndef TQT_MODULE_TABLE
-#define QT_NO_TABLE
+#define TQT_NO_TABLE
 #endif
 #ifndef TQT_MODULE_XML
-# define QT_NO_XML
+# define TQT_NO_XML
 #endif
 #ifndef TQT_MODULE_OPENGL
-# define QT_NO_OPENGL
+# define TQT_NO_OPENGL
 #endif
 #if !defined(TQT_MODULE_SQL)
-# define QT_NO_SQL
+# define TQT_NO_SQL
 #endif
 
 #if defined(Q_WS_MAC9)
@@ -839,8 +824,8 @@ class TQString;
 #  endif
 #endif
 
-#if !defined(Q_WS_QWS) && !defined(QT_NO_COP)
-#  define QT_NO_COP
+#if !defined(Q_WS_QWS) && !defined(TQT_NO_COP)
+#  define TQT_NO_COP
 #endif
 
 #ifndef QT_H
@@ -957,16 +942,16 @@ Q_EXPORT int qWinVersion();
 // Debugging and error handling
 //
 
-#if !defined(QT_NO_CHECK)
+#if !defined(TQT_NO_CHECK)
 #  define QT_CHECK_STATE			// check state of objects etc.
 #  define QT_CHECK_RANGE			// check range of indexes etc.
 #  define QT_CHECK_NULL				// check null pointers
 #  define QT_CHECK_MATH				// check math functions
 #endif
 
-#if !defined(QT_NO_DEBUG) && !defined(QT_DEBUG)
+#if !defined(TQT_NO_DEBUG) && !defined(QT_DEBUG)
 #  define QT_DEBUG				// display debug messages
-#  if !defined(QT_NO_COMPAT)			// compatibility with TQt 2
+#  if !defined(TQT_NO_COMPAT)			// compatibility with TQt 2
 #    if !defined(NO_DEBUG) && !defined(DEBUG)
 #      if !defined(Q_OS_MACX)			// clash with MacOS X headers
 #        define DEBUG
@@ -1002,28 +987,6 @@ Q_EXPORT void tqFatal( const char *, ... )    // print fatal message and exit
 
 Q_EXPORT void tqSystemWarning( const char *, int code = -1 );
 
-#if !defined(QT_CLEAN_NAMESPACE) 		// compatibility with TQt 1
-
-Q_EXPORT void debug( const char *, ... )	// print debug message
-#if defined(Q_CC_GNU) && !defined(__INSURE__)
-    __attribute__ ((format (printf, 1, 2)))
-#endif
-;
-
-Q_EXPORT void warning( const char *, ... )	// print warning message
-#if defined(Q_CC_GNU) && !defined(__INSURE__)
-    __attribute__ ((format (printf, 1, 2)))
-#endif
-;
-
-Q_EXPORT void fatal( const char *, ... )	// print fatal message and exit
-#if defined(Q_CC_GNU) && !defined(__INSURE__)
-    __attribute__ ((format (printf, 1, 2)))
-#endif
-;
-
-#endif // QT_CLEAN_NAMESPACE
-
 
 #if !defined(Q_ASSERT)
 #  if defined(QT_CHECK_STATE)
@@ -1037,13 +1000,13 @@ Q_EXPORT void fatal( const char *, ... )	// print fatal message and exit
 #  endif
 #endif
 
-#if !defined(QT_NO_COMPAT)			// compatibility with TQt 2
+#if !defined(TQT_NO_COMPAT)			// compatibility with TQt 2
 #  if !defined(ASSERT)
 #    if !defined(Q_OS_TEMP)
 #      define ASSERT(x) Q_ASSERT(x)
 #    endif
 #  endif
-#endif // QT_NO_COMPAT
+#endif // TQT_NO_COMPAT
 
 
 Q_EXPORT bool tqt_check_pointer( bool c, const char *, int );
@@ -1054,20 +1017,14 @@ Q_EXPORT bool tqt_check_pointer( bool c, const char *, int );
 #  define TQ_CHECK_PTR(p)
 #endif
 
-#if !defined(QT_NO_COMPAT)			// compatibility with TQt 2
-#  if !defined(CHECK_PTR)
-#    define CHECK_PTR(x) TQ_CHECK_PTR(x)
-#  endif
-#endif // QT_NO_COMPAT
-
 enum TQtMsgType { TQtDebugMsg, TQtWarningMsg, TQtFatalMsg };
 
 typedef void (*TQtMsgHandler)(TQtMsgType, const char *);
 Q_EXPORT TQtMsgHandler qInstallMsgHandler( TQtMsgHandler );
 
-#if !defined(QT_NO_COMPAT)			// compatibility with TQt 2
+#if !defined(TQT_NO_COMPAT)			// compatibility with TQt 2
 typedef TQtMsgHandler msg_handler;
-#endif // QT_NO_COMPAT
+#endif // TQT_NO_COMPAT
 
 Q_EXPORT void tqSuppressObsoleteWarnings( bool = TRUE );
 
@@ -1117,13 +1074,13 @@ Q_EXPORT const char *tqInstallPathShare();
 /*
  Avoid some particularly useless warnings from some stupid compilers.
  To get ALL C++ compiler warnings, define QT_CC_WARNINGS or comment out
- the line "#define QT_NO_WARNINGS"
+ the line "#define TQT_NO_WARNINGS"
 */
 
 #if !defined(QT_CC_WARNINGS)
-#  define QT_NO_WARNINGS
+#  define TQT_NO_WARNINGS
 #endif
-#if defined(QT_NO_WARNINGS)
+#if defined(TQT_NO_WARNINGS)
 #  if defined(Q_CC_MSVC)
 #    pragma warning(disable: 4244) // 'conversion' conversion from 'type1' to 'type2', possible loss of data
 #    pragma warning(disable: 4275) // non - DLL-interface classkey 'identifier' used as base for DLL-interface classkey 'identifier'
