@@ -4,6 +4,7 @@
 **
 ** Created : 920609
 **
+** Copyright (C) 2015 Timothy Pearson. All rights reserved.
 ** Copyright (C) 1992-2008 Trolltech ASA.  All rights reserved.
 **
 ** This file is part of the tools module of the TQt GUI Toolkit.
@@ -45,11 +46,11 @@
 #include "ntqcstring.h"
 #endif // QT_H
 
-#ifndef QT_NO_CAST_ASCII
+#ifndef TQT_NO_CAST_ASCII
 #include <limits.h>
 #endif
 
-#ifndef QT_NO_STL
+#ifndef TQT_NO_STL
 #if defined ( Q_CC_MSVC_NET ) && _MSC_VER < 1310 // Avoids nasty warning for xlocale, line 450
 #  pragma warning ( push )
 #  pragma warning ( disable : 4189 )
@@ -63,6 +64,9 @@
 #endif
 #endif
 
+#ifndef TQT_NO_SPRINTF
+#include <stdarg.h>
+#endif
 
 /*****************************************************************************
   TQString class
@@ -202,7 +206,7 @@ public:
 #else
     ushort &unicode() { return ucs; }
 #endif
-#ifndef QT_NO_CAST_ASCII
+#ifndef TQT_NO_CAST_ASCII
     // like all ifdef'd code this is undocumented
     operator char() const { return latin1(); }
 #endif
@@ -402,17 +406,17 @@ public:
     TQString( const TQString & );                 // impl-shared copy
     TQString( const TQByteArray& );               // deep copy
     TQString( const TQChar* unicode, uint length ); // deep copy
-#ifndef QT_NO_CAST_ASCII
+#ifndef TQT_NO_CAST_ASCII
     TQString( const char *str );                 // deep copy
 #endif
-#ifndef QT_NO_STL
+#ifndef TQT_NO_STL
     TQString( const std::string& );                   // deep copy
 #endif
     ~TQString();
 
     TQString    &operator=( const TQString & );   // impl-shared copy
     TQString    &operator=( const char * );      // deep copy
-#ifndef QT_NO_STL
+#ifndef TQT_NO_STL
     TQString    &operator=( const std::string& );     // deep copy
 #endif
     TQString    &operator=( const TQCString& );   // deep copy
@@ -449,10 +453,15 @@ public:
     TQString arg( const TQString& a1, const TQString& a2, const TQString& a3,
 		 const TQString& a4 ) const;
 
-#ifndef QT_NO_SPRINTF
+#ifndef TQT_NO_SPRINTF
     TQString    &sprintf( const char* format, ... )
 #if defined(Q_CC_GNU) && !defined(__INSURE__)
         __attribute__ ((format (printf, 2, 3)))
+#endif
+        ;
+    TQString    &vsprintf(const char *format, va_list ap)
+#if defined(Q_CC_GNU) && !defined(__INSURE__)
+        __attribute__ ((format (printf, 2, 0)))
 #endif
         ;
 #endif
@@ -460,29 +469,29 @@ public:
     int         find( TQChar c, int index=0, bool cs=TRUE ) const;
     int         find( char c, int index=0, bool cs=TRUE ) const;
     int         find( const TQString &str, int index=0, bool cs=TRUE ) const;
-#ifndef QT_NO_REGEXP
+#ifndef TQT_NO_REGEXP
     int         find( const TQRegExp &, int index=0 ) const;
 #endif
-#ifndef QT_NO_CAST_ASCII
+#ifndef TQT_NO_CAST_ASCII
     int         find( const char* str, int index=0 ) const;
 #endif
     int         findRev( TQChar c, int index=-1, bool cs=TRUE) const;
     int         findRev( char c, int index=-1, bool cs=TRUE) const;
     int         findRev( const TQString &str, int index=-1, bool cs=TRUE) const;
-#ifndef QT_NO_REGEXP
+#ifndef TQT_NO_REGEXP
     int         findRev( const TQRegExp &, int index=-1 ) const;
 #endif
-#ifndef QT_NO_CAST_ASCII
+#ifndef TQT_NO_CAST_ASCII
     int         findRev( const char* str, int index=-1 ) const;
 #endif
     int         contains( TQChar c, bool cs=TRUE ) const;
     int         contains( char c, bool cs=TRUE ) const
                     { return contains(TQChar(c), cs); }
-#ifndef QT_NO_CAST_ASCII
+#ifndef TQT_NO_CAST_ASCII
     int         contains( const char* str, bool cs=TRUE ) const;
 #endif
     int         contains( const TQString &str, bool cs=TRUE ) const;
-#ifndef QT_NO_REGEXP
+#ifndef TQT_NO_REGEXP
     int         contains( const TQRegExp & ) const;
 #endif
 
@@ -495,11 +504,11 @@ public:
     };
     TQString     section( TQChar sep, int start, int end = 0xffffffff, int flags = SectionDefault ) const;
     TQString     section( char sep, int start, int end = 0xffffffff, int flags = SectionDefault ) const;
-#ifndef QT_NO_CAST_ASCII
+#ifndef TQT_NO_CAST_ASCII
     TQString      section( const char *in_sep, int start, int end = 0xffffffff, int flags = SectionDefault ) const;
 #endif
     TQString     section( const TQString &in_sep, int start, int end = 0xffffffff, int flags = SectionDefault ) const;
-#ifndef QT_NO_REGEXP
+#ifndef TQT_NO_REGEXP
     TQString     section( const TQRegExp &reg, int start, int end = 0xffffffff, int flags = SectionDefault ) const;
 #endif
 
@@ -517,7 +526,7 @@ public:
     TQString     simplifyWhiteSpace()    const;
 
     TQString    &insert( uint index, const TQString & );
-#ifndef QT_NO_CAST_ASCII
+#ifndef TQT_NO_CAST_ASCII
     TQString    &insert( uint index, const TQByteArray & );
     TQString    &insert( uint index, const char * );
 #endif
@@ -527,21 +536,21 @@ public:
     TQString    &append( char );
     TQString    &append( TQChar );
     TQString    &append( const TQString & );
-#ifndef QT_NO_CAST_ASCII
+#ifndef TQT_NO_CAST_ASCII
     TQString    &append( const TQByteArray & );
     TQString    &append( const char * );
 #endif
-#if !defined(QT_NO_STL) && !defined(QT_NO_CAST_ASCII)
+#if !defined(TQT_NO_STL) && !defined(TQT_NO_CAST_ASCII)
     TQString    &append( const std::string& );
 #endif
     TQString    &prepend( char );
     TQString    &prepend( TQChar );
     TQString    &prepend( const TQString & );
-#ifndef QT_NO_CAST_ASCII
+#ifndef TQT_NO_CAST_ASCII
     TQString    &prepend( const TQByteArray & );
     TQString    &prepend( const char * );
 #endif
-#if !defined(QT_NO_STL) && !defined(QT_NO_CAST_ASCII)
+#if !defined(TQT_NO_STL) && !defined(TQT_NO_CAST_ASCII)
     TQString    &prepend( const std::string& );
 #endif
     TQString    &remove( uint index, uint len );
@@ -555,10 +564,10 @@ public:
     TQString    &remove( TQChar c );
     TQString    &remove( char c )
     { return remove( TQChar(c) ); }
-#ifndef QT_NO_CAST_ASCII
+#ifndef TQT_NO_CAST_ASCII
     TQString    &remove( const char * );
 #endif
-#ifndef QT_NO_REGEXP
+#ifndef TQT_NO_REGEXP
     TQString    &remove( const TQRegExp & );
 #endif
     TQString    &replace( uint index, uint len, const TQString & );
@@ -586,7 +595,7 @@ public:
     TQString    &replace( const TQString &, const TQString & );
     TQString    &replace( const TQString &, const TQString &, bool );
 #endif
-#ifndef QT_NO_REGEXP_CAPTURE
+#ifndef TQT_NO_REGEXP_CAPTURE
     TQString    &replace( const TQRegExp &, const TQString & );
 #endif
     TQString    &replace( TQChar, TQChar );
@@ -624,11 +633,11 @@ public:
     void        setExpand( uint index, TQChar c );
 
     TQString    &operator+=( const TQString &str );
-#ifndef QT_NO_CAST_ASCII
+#ifndef TQT_NO_CAST_ASCII
     TQString    &operator+=( const TQByteArray &str );
     TQString    &operator+=( const char *str );
 #endif
-#if !defined(QT_NO_STL) && !defined(QT_NO_CAST_ASCII)
+#if !defined(TQT_NO_STL) && !defined(TQT_NO_CAST_ASCII)
     TQString    &operator+=( const std::string& );
 #endif
     TQString    &operator+=( TQChar c );
@@ -654,10 +663,10 @@ public:
     TQCString local8Bit() const;
     static TQString fromLocal8Bit(const char*, int len=-1);
     bool operator!() const;
-#ifndef QT_NO_ASCII_CAST
+#ifndef TQT_NO_ASCII_CAST
     operator const char *() const { return ascii(); }
 #endif
-#ifndef QT_NO_STL
+#ifndef TQT_NO_STL
     operator std::string() const { return ascii() ? ascii() : ""; }
 #endif
 
@@ -677,13 +686,13 @@ public:
     static int localeAwareCompare( const TQString& s1, const TQString& s2 )
     { return s1.localeAwareCompare( s2 ); }
 
-#ifndef QT_NO_DATASTREAM
+#ifndef TQT_NO_DATASTREAM
     friend Q_EXPORT TQDataStream &operator>>( TQDataStream &, TQString & );
 #endif
 
     void compose();
 
-#ifndef QT_NO_COMPAT
+#ifndef TQT_NO_COMPAT
     const char* data() const { return ascii(); }
 #endif
 
@@ -722,7 +731,7 @@ private:
 
     void checkSimpleText() const;
     void grow( uint newLength );
-#ifndef QT_NO_CAST_ASCII
+#ifndef TQT_NO_CAST_ASCII
     TQString &insertHelper( uint index, const char *s, uint len=UINT_MAX );
     TQString &operatorPlusEqHelper( const char *s, uint len2=UINT_MAX );
 #endif
@@ -820,7 +829,7 @@ public:
 /*****************************************************************************
   TQString stream functions
  *****************************************************************************/
-#ifndef QT_NO_DATASTREAM
+#ifndef TQT_NO_DATASTREAM
 Q_EXPORT TQDataStream &operator<<( TQDataStream &, const TQString & );
 Q_EXPORT TQDataStream &operator>>( TQDataStream &, TQString & );
 #endif
@@ -839,7 +848,7 @@ inline TQString TQString::section( TQChar sep, int start, int end, int flags ) c
 inline TQString TQString::section( char sep, int start, int end, int flags ) const
 { return section(TQChar(sep), start, end, flags); }
 
-#ifndef QT_NO_CAST_ASCII
+#ifndef TQT_NO_CAST_ASCII
 inline TQString TQString::section( const char *in_sep, int start, int end, int flags ) const
 { return section(TQString(in_sep), start, end, flags); }
 #endif
@@ -868,7 +877,7 @@ inline bool TQString::isEmpty() const
 inline TQString TQString::copy() const
 { return TQString( *this ); }
 
-#ifndef QT_NO_CAST_ASCII
+#ifndef TQT_NO_CAST_ASCII
 inline TQString &TQString::insert( uint index, const char *s )
 { return insertHelper( index, s ); }
 
@@ -888,12 +897,12 @@ inline TQString &TQString::prepend( TQChar c )
 inline TQString &TQString::prepend( char c )
 { return insert(0,c); }
 
-#ifndef QT_NO_CAST_ASCII
+#ifndef TQT_NO_CAST_ASCII
 inline TQString &TQString::prepend( const TQByteArray & s )
 { return insert(0,s); }
 #endif
 
-#ifndef QT_NO_CAST_ASCII
+#ifndef TQT_NO_CAST_ASCII
 inline TQString &TQString::operator+=( const TQByteArray &s )
 {
     int pos = s.find( 0 );
@@ -904,7 +913,7 @@ inline TQString &TQString::operator+=( const TQByteArray &s )
 inline TQString &TQString::append( const TQString & s )
 { return operator+=(s); }
 
-#ifndef QT_NO_CAST_ASCII
+#ifndef TQT_NO_CAST_ASCII
 inline TQString &TQString::append( const TQByteArray &s )
 { return operator+=(s); }
 
@@ -918,10 +927,10 @@ inline TQString &TQString::append( TQChar c )
 inline TQString &TQString::append( char c )
 { return operator+=(c); }
 
-#ifndef QT_NO_STL
+#ifndef TQT_NO_STL
 inline TQString &TQString::operator=( const std::string& str )
 { return operator=(str.c_str()); }
-#ifndef QT_NO_CAST_ASCII
+#ifndef TQT_NO_CAST_ASCII
 inline TQString &TQString::operator+=( const std::string& s )
 { return operator+=(s.c_str()); }
 inline TQString &TQString::append( const std::string& s )
@@ -978,7 +987,7 @@ inline int TQString::find( char c, int index, bool cs ) const
 inline int TQString::findRev( char c, int index, bool cs ) const
 { return findRev( TQChar(c), index, cs ); }
 
-#ifndef QT_NO_CAST_ASCII
+#ifndef TQT_NO_CAST_ASCII
 inline int TQString::find( const char* str, int index ) const
 { return find(TQString::fromAscii(str), index); }
 
@@ -997,7 +1006,7 @@ Q_EXPORT bool operator<=( const TQString &s1, const TQString &s2 );
 Q_EXPORT bool operator==( const TQString &s1, const TQString &s2 );
 Q_EXPORT bool operator>( const TQString &s1, const TQString &s2 );
 Q_EXPORT bool operator>=( const TQString &s1, const TQString &s2 );
-#ifndef QT_NO_CAST_ASCII
+#ifndef TQT_NO_CAST_ASCII
 Q_EXPORT bool operator!=( const TQString &s1, const char *s2 );
 Q_EXPORT bool operator<( const TQString &s1, const char *s2 );
 Q_EXPORT bool operator<=( const TQString &s1, const char *s2 );
@@ -1019,7 +1028,7 @@ Q_EXPORT inline const TQString operator+( const TQString &s1, const TQString &s2
     return tmp;
 }
 
-#ifndef QT_NO_CAST_ASCII
+#ifndef TQT_NO_CAST_ASCII
 Q_EXPORT inline const TQString operator+( const TQString &s1, const char *s2 )
 {
     TQString tmp( s1 );
@@ -1065,7 +1074,7 @@ Q_EXPORT inline const TQString operator+( char c1, const TQString &s2 )
     return tmp;
 }
 
-#ifndef QT_NO_STL
+#ifndef TQT_NO_STL
 Q_EXPORT inline const TQString operator+(const TQString& s1, const std::string& s2)
 {
     return s1 + TQString(s2);
