@@ -284,7 +284,6 @@ KDCOPWindow::KDCOPWindow(TQWidget *parent, const char * name)
   : TDEMainWindow(parent, name)
 {
   dcopClient = kapp->dcopClient();
-  dcopClient->attach();
   resize( 377, 480 );
   statusBar()->message(i18n("Welcome to the TDE DCOP browser"));
   setIcon(TDEGlobal::iconLoader()->loadIcon("enhanced_browsing", TDEIcon::NoGroup, TDEIcon::SizeSmall));
@@ -318,7 +317,7 @@ KDCOPWindow::KDCOPWindow(TQWidget *parent, const char * name)
       "application-x-executable",
      CTRL + Key_E,
      TQT_TQOBJECT(this),
-     TQT_SLOT(slotCallFunction()),
+     TQT_SLOT(slotItemExecuted()),
      actionCollection(),
      "execute"
     );
@@ -370,7 +369,7 @@ void KDCOPWindow::slotCurrentChanged( TQListViewItem* i )
 }
 
 
-void KDCOPWindow::slotCallFunction()
+void KDCOPWindow::slotItemExecuted()
 {
   slotCallFunction( mainView->lv->currentItem() );
 }
@@ -387,7 +386,10 @@ void KDCOPWindow::slotCallFunction( TQListViewItem* it )
   DCOPBrowserItem * item = static_cast<DCOPBrowserItem *>(it);
 
   if (item->type() != DCOPBrowserItem::Function)
+  {
+    it->setOpen(!it->isOpen());
     return;
+  }
 
   DCOPBrowserFunctionItem * fitem =
     static_cast<DCOPBrowserFunctionItem *>(item);
@@ -870,11 +872,7 @@ void KDCOPWindow::slotCallFunction( TQListViewItem* it )
       TQDataStream reply(replyData, IO_ReadOnly);
       if (demarshal(replyType, reply, mainView->lb_replyData))
 	{
-      mainView->l_replyType->setText
-        (
-         i18n("<strong>%1</strong>")
-         .arg(TQString::fromUtf8(replyType))
-        );
+	mainView->l_replyType->setText(i18n("<strong>%1</strong>").arg(TQString::fromUtf8(replyType)));
 	mainView->lb_replyData->show();
 	}
 	else
@@ -912,12 +910,7 @@ void KDCOPWindow::slotFillApplications()
   TDEApplication::restoreOverrideCursor();
 }
 
-bool KDCOPWindow::demarshal
-(
- TQCString &   replyType,
- TQDataStream & reply,
- TQListBox	*theList
-)
+bool KDCOPWindow::demarshal(TQCString &replyType, TQDataStream &reply, TQListBox *theList)
 {
   TQStringList ret;
   TQPixmap pret;
@@ -1080,6 +1073,15 @@ bool KDCOPWindow::demarshal
 	reply >> r;
 	ret << r.toString();
   }
+  else if (replyType == "TQStringVariantMap")
+  {
+    TQStringVariantMap r;
+    reply >> r;
+    for (TQStringVariantMap::ConstIterator it(r.begin()); it != r.end(); ++it)
+    {
+      ret << it.key() + " : " + it.data().toString();
+    }
+  }
   else if (replyType == "DCOPRef")
   {
 	DCOPRef r;
@@ -1089,8 +1091,7 @@ bool KDCOPWindow::demarshal
   }
   else
   {
-    ret <<
-      i18n("Do not know how to demarshal %1").arg(TQString::fromUtf8(replyType));
+    ret << i18n("Do not know how to demarshal %1").arg(TQString::fromUtf8(replyType));
 	isValid = false;
   }
 
