@@ -1440,7 +1440,7 @@ void MainWindow::createNewTemplate()
     }
 
     TQStringList templRoots;
-    const char *qtdir = getenv( "QTDIR" );
+    const char *qtdir = getenv( "TQTDIR" );
     if(qtdir)
 	templRoots << qtdir;
     templRoots << tqInstallPathData();
