@@ -199,9 +199,22 @@ public:
   bool htmlOverride() const { return mHtmlOverride; }
   void setHtmlOverride( bool override );
 
-  /** Override default load external references setting */
+  /** Get the load external references override setting */
   bool htmlLoadExtOverride() const { return mHtmlLoadExtOverride; }
-  void setHtmlLoadExtOverride( bool override );
+
+  /** Default behavior for loading external references.
+   *  Use this for specifying the external reference loading behavior as
+   *  specified in the user settings.
+   *  @see setHtmlLoadExtOverride
+   */
+  void setHtmlLoadExtDefault(bool loadExtDefault);
+
+  /** Override default load external references setting
+   *  @warning This must only be called when the user has explicitly
+   *  been asked to retrieve external references!
+   *  @see setHtmlLoadExtDefault
+   */
+  void setHtmlLoadExtOverride(bool loadExtOverride);
 
   /** Is html mail to be supported? Takes into account override */
   bool htmlMail();
@@ -244,6 +257,7 @@ public:
   // Action to reply to a message
   // but action( "some_name" ) some name could be used instead.
   TDEToggleAction *toggleFixFontAction() { return mToggleFixFontAction; }
+  TDEToggleAction *toggleMimePartTreeAction() { return mToggleMimePartTreeAction; }
   TDEAction *mailToComposeAction() { return mMailToComposeAction; }
   TDEAction *mailToReplyAction() { return mMailToReplyAction; }
   TDEAction *mailToForwardAction() { return mMailToForwardAction; }
@@ -397,10 +411,13 @@ public slots:
   /** The user toggled the "Fixed Font" flag from the view menu. */
   void slotToggleFixedFont();
 
+  /** Show or hide the Mime Tree Viewer */
+  void slotToggleMimePartTree();
+
   /** Copy the selected text to the clipboard */
   void slotCopySelectedText();
 
-   void slotUrlClicked();
+  void slotUrlClicked();
 
   /** Operations on mailto: URLs. */
   void slotMailtoReply();
@@ -540,7 +557,7 @@ private:
   TQString renderAttachments( partNode *node, const TQColor &bgColor );
 
 private:
-  bool mHtmlMail, mHtmlLoadExternal, mHtmlOverride, mHtmlLoadExtOverride;
+  bool mHtmlMail, mHtmlLoadExtDefault, mHtmlOverride, mHtmlLoadExtOverride;
   int mAtmCurrent;
   TQString mAtmCurrentName;
   KMMessage *mMessage;
@@ -581,6 +598,7 @@ private:
   TQStringList mTempFiles;
   TQStringList mTempDirs;
   int mMimeTreeMode;
+  int mMimeTreeModeOverride;
   bool mMimeTreeAtBottom;
   TQValueList<int> mSplitterSizes;
   partNode* mRootNode;
@@ -593,6 +611,7 @@ private:
   TDEToggleAction *mHeaderOnlyAttachmentsAction;
   TDESelectAction *mSelectEncodingAction;
   TDEToggleAction *mToggleFixFontAction;
+  TDEToggleAction *mToggleMimePartTreeAction;
 
   KURL mHoveredUrl;
   KURL mClickedUrl;
