@@ -796,7 +796,7 @@ void MainWindow::createNewTemplate()
   }
 
   TQStringList templRoots;
-  const char *qtdir = getenv("QTDIR");
+  const char *qtdir = getenv("TQTDIR");
   if (qtdir)
     templRoots << qtdir;
 #ifdef TQT_INSTALL_PREFIX
