@@ -1683,13 +1683,13 @@ TQVariant WidgetFactory::defaultValue( TQObject *w, const TQString &propName )
 {
     if ( propName == "wordwrap" ) {
 	int v = defaultValue( w, "alignment" ).toInt();
-	return TQVariant( ( v & WordBreak ) == WordBreak, 0 );
+	return TQVariant( ( v & WordBreak ) == WordBreak );
     } else if ( propName == "toolTip" || propName == "whatsThis" ) {
 	return TQVariant( TQString::fromLatin1( "" ) );
     } else if ( w->inherits( "CustomWidget" ) ) {
 	return TQVariant();
     } else if ( propName == "frameworkCode" ) {
-	return TQVariant( true, 0 );
+	return TQVariant( true );
     } else if ( propName == "layoutMargin" ) {
 	if ( w->inherits( "TQLayoutWidget" ) )
 	    return TQVariant( 0 );
