@@ -689,14 +689,15 @@ void AppearanceConfig::slotDeleteChatStyle()
 void AppearanceConfig::slotGetChatStyles()
 {
 	// we need this because TDENewStuffGeneric's install function isn't clever enough
-	KopeteStyleNewStuff *kopeteNewStuff = new KopeteStyleNewStuff( "kopete style 0.12+", this );
-	KNS::Engine *engine = new KNS::Engine( kopeteNewStuff, "kopete style 0.12+", this );
+	TQString contentType="Kopete Styles";
+	KopeteStyleNewStuff *kopeteNewStuff = new KopeteStyleNewStuff( contentType, this );
+	KNS::Engine *engine = new KNS::Engine( kopeteNewStuff, contentType, this );
 	KNS::DownloadDialog *downloadDialog = new KNS::DownloadDialog( engine, this );
-	downloadDialog->setType( "kopete style 0.12+" );
+	downloadDialog->setType( contentType );
 	// you have to do this by hand when providing your own Engine
 	KNS::ProviderLoader *provider = new KNS::ProviderLoader( this );
 	TQObject::connect( provider, TQT_SIGNAL( providersLoaded(Provider::List*) ), downloadDialog, TQT_SLOT( slotProviders (Provider::List *) ) );
-	provider->load( "kopete style 0.12+", "https://www.trinitydesktop.org/ocs/providers.xml" );
+	provider->load( contentType, "https://www.trinitydesktop.org/ocs/providers.xml" );
 	downloadDialog->exec();
 }
 
