@@ -1515,7 +1515,7 @@ void JabberAccount::slotGroupChatError (const XMPP::Jid &jid, int error, const T
 	{
 	case JabberClient::InvalidPasswordForMUC:
 		{
-			TQCString password;
+			TQString password;
  			int result = KPasswordDialog::getPassword(password, i18n("A password is required to join the room %1.").arg(jid.node()));
 			if (result == KPasswordDialog::Accepted)
 				m_jabberClient->joinGroupChat(jid.domain(), jid.node(), jid.resource(), password);
@@ -1752,5 +1752,3 @@ void JabberAccount::slotUnregisterFinished( )
 
 
 #include "jabberaccount.moc"
-
-// vim: set noet ts=4 sts=4 sw=4:
