@@ -592,6 +592,7 @@ KSMServer::KSMServer( const TQString& windowManager, const TQString& windowManag
     state = Idle;
     dialogActive = false;
     saveSession = false;
+    m_startupCompleted = false;
     wmPhase1WaitingCount = 0;
     TDEConfig* config = TDEGlobal::config();
     config->setGroup("General" );
@@ -990,3 +991,8 @@ bool KSMServer::defaultSession() const
 {
     return sessionGroup.isEmpty();
 }
+
+bool KSMServer::startupCompleted()
+{
+	  return m_startupCompleted;
+}
