@@ -101,7 +101,7 @@ void dockwidget::showWeather()
                m_weatherService->stationName( m_locationCode ) + " (" +
                m_weatherService->stationCountry( m_locationCode ) + ")</nobr></center></h3>";
 
-        if ( m_weatherService->currentIconString( m_locationCode ) == "dunno" )  // no data
+        if ( m_weatherService->currentIconString( m_locationCode ) == "weather-none-available" )  // no data
             tip += "<center><nobr>" + i18n("The network is currently offline...") + "</nobr></center>";
 
         tip += TQString("<br><table>"
