@@ -24,6 +24,7 @@
 #include <kdebug.h>
 #include <tdeapplication.h>
 #include <kiconloader.h>
+#include <tdemessagebox.h>
 #include <dcopref.h>
 #include <dcopclient.h>
 
@@ -43,8 +44,7 @@ enum {
  LAYOUT_COLUMN_NAME = 1,
  LAYOUT_COLUMN_MAP = 2,
  LAYOUT_COLUMN_VARIANT = 3,
- LAYOUT_COLUMN_INCLUDE = 4,
- LAYOUT_COLUMN_DISPLAY_NAME = 5,
+ LAYOUT_COLUMN_DISPLAY_NAME = 4,
  SRC_LAYOUT_COLUMN_COUNT = 3,
  DST_LAYOUT_COLUMN_COUNT = 6
 };
@@ -100,7 +100,8 @@ static TQListViewItem* copyLVI(const TQListViewItem* src, TQListView* parent)
 
 LayoutConfig::LayoutConfig(TQWidget *parent, const char *name)
   : TDECModule(parent, name),
-    m_rules(NULL)
+    m_rules(NULL),
+    m_forceGrpOverwrite(false)
 {
   TQVBoxLayout *main = new TQVBoxLayout(this, 0, KDialog::spacingHint());
 
@@ -110,6 +111,9 @@ LayoutConfig::LayoutConfig(TQWidget *parent, const char *name)
   connect( TQT_TQOBJECT(widget->chkEnable), TQT_SIGNAL( toggled( bool )), TQT_TQOBJECT(this), TQT_SLOT(changed()));
   connect( TQT_TQOBJECT(widget->chkShowSingle), TQT_SIGNAL( toggled( bool )), TQT_TQOBJECT(this), TQT_SLOT(changed()));
 
+  connect( TQT_TQOBJECT(widget->comboHotkey), TQT_SIGNAL(activated(int)), TQT_TQOBJECT(this), TQT_SLOT(hotkeyComboChanged()));
+  connect( TQT_TQOBJECT(widget->comboHotkey), TQT_SIGNAL(activated(int)), TQT_TQOBJECT(this), TQT_SLOT(updateOptionsCommand()));
+  connect( TQT_TQOBJECT(widget->comboHotkey), TQT_SIGNAL(activated(int)), TQT_TQOBJECT(this), TQT_SLOT(changed()));
   connect( TQT_TQOBJECT(widget->comboModel), TQT_SIGNAL(activated(int)), TQT_TQOBJECT(this), TQT_SLOT(changed()));
 
   connect( TQT_TQOBJECT(widget->listLayoutsSrc), TQT_SIGNAL(doubleClicked(TQListViewItem*,const TQPoint&, int)),
@@ -124,9 +128,6 @@ LayoutConfig::LayoutConfig(TQWidget *parent, const char *name)
 
   connect( widget->editDisplayName, TQT_SIGNAL(textChanged(const TQString&)), TQT_TQOBJECT(this), TQT_SLOT(displayNameChanged(const TQString&)));
 
-  connect( widget->chkLatin, TQT_SIGNAL(clicked()), TQT_TQOBJECT(this), TQT_SLOT(changed()));
-  connect( widget->chkLatin, TQT_SIGNAL(clicked()), TQT_TQOBJECT(this), TQT_SLOT(latinChanged()));
-
   widget->btnUp->setIconSet(SmallIconSet("1uparrow"));
   connect( widget->btnUp, TQT_SIGNAL(clicked()), TQT_TQOBJECT(this), TQT_SLOT(changed()));
   connect( widget->btnUp, TQT_SIGNAL(clicked()), TQT_TQOBJECT(this), TQT_SLOT(moveUp()));
@@ -149,16 +150,12 @@ LayoutConfig::LayoutConfig(TQWidget *parent, const char *name)
 
   widget->listLayoutsSrc->setColumnText(LAYOUT_COLUMN_FLAG, "");
   widget->listLayoutsDst->setColumnText(LAYOUT_COLUMN_FLAG, "");
-  widget->listLayoutsDst->setColumnText(LAYOUT_COLUMN_INCLUDE, "");
 //  widget->listLayoutsDst->setColumnText(LAYOUT_COLUMN_DISPLAY_NAME, "");
 
   widget->listLayoutsSrc->setColumnWidth(LAYOUT_COLUMN_FLAG, 28);
   widget->listLayoutsDst->setColumnWidth(LAYOUT_COLUMN_FLAG, 28);
 
-  widget->listLayoutsDst->header()->setResizeEnabled(FALSE, LAYOUT_COLUMN_INCLUDE);
   widget->listLayoutsDst->header()->setResizeEnabled(FALSE, LAYOUT_COLUMN_DISPLAY_NAME);
-  widget->listLayoutsDst->setColumnWidthMode(LAYOUT_COLUMN_INCLUDE, TQListView::Manual);
-  widget->listLayoutsDst->setColumnWidth(LAYOUT_COLUMN_INCLUDE, 0);
 //  widget->listLayoutsDst->setColumnWidth(LAYOUT_COLUMN_DISPLAY_NAME, 0);
 
   widget->listLayoutsDst->setSorting(-1);
@@ -212,7 +209,6 @@ void LayoutConfig::initUI() {
 				TQListViewItem* newItem = copyLVI(srcItem, widget->listLayoutsDst);
 
 				newItem->setText(LAYOUT_COLUMN_VARIANT, layoutUnit.variant);
-				newItem->setText(LAYOUT_COLUMN_INCLUDE, layoutUnit.includeGroup);
 				newItem->setText(LAYOUT_COLUMN_DISPLAY_NAME, layoutUnit.displayName);
 				widget->listLayoutsDst->insertItem(newItem);
 				newItem->moveItem(widget->listLayoutsDst->lastItem());
@@ -222,6 +218,25 @@ void LayoutConfig::initUI() {
 		}
 	}
 
+	// initialize hotkey combo
+	TQDict<char> allOptions = m_rules->options();
+
+	TQStringList commonHotkeys;
+	commonHotkeys << "alt_shift_toggle" << "ctrl_shift_toggle"
+	              << "win_space_toggle" << "alt_space_toggle"
+	              << "caps_toggle" << "menu_toggle"
+	              << "lwin_toggle" << "rwin_toggle";
+
+	for (TQStringList::ConstIterator hk = commonHotkeys.begin(); hk != commonHotkeys.end(); ++hk ) {
+		const char *hkOpt  = tqstrdup(TQString("grp:" + (*hk)).ascii());
+		const char *hkDesc = allOptions[hkOpt];
+		if (hkDesc != 0) { // the option exists
+			widget->comboHotkey->insertItem(i18n(hkDesc));
+		}
+	}
+	widget->comboHotkey->insertItem(i18n("None"));
+	widget->comboHotkey->insertItem(i18n("Other..."));
+
 	// display KXKB switching options
 	widget->chkShowSingle->setChecked(m_kxkbConfig.m_showSingle);
 
@@ -231,16 +246,22 @@ void LayoutConfig::initUI() {
 	widget->radFlagOnly->setChecked( showFlag && !showLabel );
 	widget->radLabelOnly->setChecked( !showFlag && showLabel );
 
-	widget->chkEnableOptions->setChecked( m_kxkbConfig.m_enableXkbOptions );
-	widget->checkResetOld->setChecked(m_kxkbConfig.m_resetOldOptions);
+	widget->xkbOptsMode->setButton(m_kxkbConfig.m_resetOldOptions ? 0 : 1);
 
 	widget->grpLabel->setButton( ( m_kxkbConfig.m_useThemeColors ? 0 : 1 )  );
 	widget->bgColor->setColor( m_kxkbConfig.m_colorBackground );
 	widget->fgColor->setColor( m_kxkbConfig.m_colorLabel );
+	widget->chkBgTransparent->setChecked( m_kxkbConfig.m_bgTransparent );
 	widget->labelFont->setFont( m_kxkbConfig.m_labelFont );
 	widget->chkLabelShadow->setChecked( m_kxkbConfig.m_labelShadow );
 	widget->shColor->setColor( m_kxkbConfig.m_colorShadow );
 
+	widget->grpLabel->setDisabled(showFlag && !showLabel);
+	widget->grpLabelColors->setDisabled(m_kxkbConfig.m_useThemeColors);
+	widget->labelBgColor->setDisabled(showFlag);
+	widget->bgColor->setDisabled(showFlag);
+	widget->chkBgTransparent->setDisabled(showFlag);
+
 	switch( m_kxkbConfig.m_switchingPolicy ) {
 		default:
 		case SWITCH_POLICY_GLOBAL:
@@ -262,15 +283,22 @@ void LayoutConfig::initUI() {
 
 	widget->chkEnable->setChecked( m_kxkbConfig.m_useKxkb );
 	widget->grpLayouts->setEnabled( m_kxkbConfig.m_useKxkb );
-	widget->optionsFrame->setEnabled( m_kxkbConfig.m_useKxkb );
+	widget->swOptsFrame->setEnabled( m_kxkbConfig.m_useKxkb );
+	widget->indOptsFrame->setEnabled( m_kxkbConfig.m_useKxkb );
 
 	// display xkb options
-	TQStringList options = TQStringList::split(',', m_kxkbConfig.m_options);
-	for (TQStringList::ConstIterator it = options.begin(); it != options.end(); ++it)
+	TQStringList activeOptions = TQStringList::split(',', m_kxkbConfig.m_options);
+	bool foundGrp = false;
+	for (TQStringList::ConstIterator it = activeOptions.begin(); it != activeOptions.end(); ++it)
 	{
 		TQString option = *it;
 		TQString optionKey = option.mid(0, option.find(':'));
 		TQString optionName = m_rules->options()[option];
+
+		if (optionKey == "grp") {
+			foundGrp = true;
+		}
+
 		OptionListItem *item = m_optionGroups[i18n(optionKey.latin1())];
 
 		if (item != NULL) {
@@ -286,7 +314,15 @@ void LayoutConfig::initUI() {
 		}
 	}
 
+	if (!foundGrp) {
+		OptionListItem *grpNone = itemForOption("grp:none");
+		if (grpNone) {
+			grpNone->setOn(true);
+		}
+	}
+
 	updateOptionsCommand();
+	updateHotkeyCombo(true);
 	emit TDECModule::changed( false );
 }
 
@@ -296,13 +332,13 @@ void LayoutConfig::save()
 	TQString model = lookupLocalized(m_rules->models(), widget->comboModel->currentText());
 	m_kxkbConfig.m_model = model;
 
-	m_kxkbConfig.m_enableXkbOptions = widget->chkEnableOptions->isChecked();
-	m_kxkbConfig.m_resetOldOptions = widget->checkResetOld->isChecked();
+	m_kxkbConfig.m_resetOldOptions = widget->radXkbOverwrite->isOn();
 	m_kxkbConfig.m_options = createOptionString();
 
 	m_kxkbConfig.m_useThemeColors = widget->radLabelUseTheme->isChecked();
 	m_kxkbConfig.m_colorBackground = widget->bgColor->color();
 	m_kxkbConfig.m_colorLabel = widget->fgColor->color();
+	m_kxkbConfig.m_bgTransparent = widget->chkBgTransparent->isChecked();
 	m_kxkbConfig.m_labelFont = widget->labelFont->font();
 	m_kxkbConfig.m_labelShadow = widget->chkLabelShadow->isChecked();
 	m_kxkbConfig.m_colorShadow = widget->shColor->color();
@@ -312,17 +348,14 @@ void LayoutConfig::save()
 	while (item) {
 		TQString layout = item->text(LAYOUT_COLUMN_MAP);
 		TQString variant = item->text(LAYOUT_COLUMN_VARIANT);
-		TQString includes = item->text(LAYOUT_COLUMN_INCLUDE);
 		TQString displayName = item->text(LAYOUT_COLUMN_DISPLAY_NAME);
 
 		LayoutUnit layoutUnit(layout, variant);
-		layoutUnit.includeGroup = includes;
 		layoutUnit.displayName = displayName;
 		layouts.append( layoutUnit );
 
 		item = item->nextSibling();
 		kdDebug() << "To save: layout " << layoutUnit.toPair()
-				<< ", inc: " << layoutUnit.includeGroup
 				<< ", disp: " << layoutUnit.displayName << endl;
 	}
 	m_kxkbConfig.m_layouts = layouts;
@@ -357,6 +390,35 @@ void LayoutConfig::save()
 
 	m_kxkbConfig.save();
 
+	// We might need to unset previous hotkey options
+	if (m_forceGrpOverwrite)
+	{
+		// First get all the server's options
+		TQStringList srvOptions = TQStringList::split(",", XKBExtension::getServerOptions());
+		TQStringList newOptions;
+
+		// Then remove all grp: options
+		for (TQStringList::Iterator it = srvOptions.begin(); it != srvOptions.end(); ++it)
+		{
+			TQString opt(*it);
+			if (!opt.startsWith("grp:"))
+			{
+				newOptions << opt;
+			}
+		}
+
+		XkbOptions xkbOptions;
+		xkbOptions.options = newOptions.join(",");
+		xkbOptions.resetOld = true;
+
+		if (!XKBExtension::setXkbOptions(xkbOptions))
+		{
+			kdWarning() << "[LayoutConfig::save] Could not overwrite previous grp: options!" << endl;
+		}
+
+		m_forceGrpOverwrite = false;
+	}
+
 	// Get current layout from Kxkb
 	if (!kapp->dcopClient()->isAttached())
 		kapp->dcopClient()->attach();
@@ -389,6 +451,8 @@ void LayoutConfig::save()
 		}
 	}
 
+	updateHotkeyCombo();
+
 	emit TDECModule::changed( false );
 }
 
@@ -431,9 +495,6 @@ void LayoutConfig::add()
     // than one time, with different variants.
     TQListViewItem* toadd = copyLVI(sel, widget->listLayoutsDst);
 
-    // Turn on "Include Latin layout" for new language by default (bnc:204402)
-    toadd->setText(LAYOUT_COLUMN_INCLUDE, "us");
-
     widget->listLayoutsDst->insertItem(toadd);
     if( widget->listLayoutsDst->childCount() > 1 )
 		toadd->moveItem(widget->listLayoutsDst->lastItem());
@@ -505,6 +566,7 @@ void LayoutConfig::variantChanged()
 	if( selectedVariant == DEFAULT_VARIANT_NAME )
 		selectedVariant = "";
 	selLayout->setText(LAYOUT_COLUMN_VARIANT, selectedVariant);
+	updateLayoutCommand();
 }
 
 // helper
@@ -543,33 +605,10 @@ void LayoutConfig::updateIndicator(TQListViewItem* selLayout)
 {
 }
 
-
-void LayoutConfig::latinChanged()
-{
-    TQListViewItem* selLayout = widget->listLayoutsDst->selectedItem();
-    if (  !selLayout ) {
-      widget->chkLatin->setChecked( false );
-      widget->chkLatin->setEnabled( false );
-      return;
-    }
-
-	TQString include;
-	if( widget->chkLatin->isChecked() )
-		include = "us";
-    else
-		include = "";
-	selLayout->setText(LAYOUT_COLUMN_INCLUDE, include);
-
- 	LayoutUnit layoutUnitKey = getLayoutUnitKey(selLayout);
-	kdDebug() << "layout " << layoutUnitKey.toPair() << ", inc: " << include << endl;
-}
-
 void LayoutConfig::layoutSelChanged(TQListViewItem *sel)
 {
     widget->comboVariant->clear();
     widget->comboVariant->setEnabled( sel != NULL );
-    widget->chkLatin->setChecked( false );
-    widget->chkLatin->setEnabled( sel != NULL );
 
     if( sel == NULL ) {
         updateLayoutCommand();
@@ -580,21 +619,6 @@ void LayoutConfig::layoutSelChanged(TQListViewItem *sel)
 	LayoutUnit layoutUnitKey = getLayoutUnitKey(sel);
 	TQString kbdLayout = layoutUnitKey.layout;
 
-	// TODO: need better algorithm here for determining if needs us group
-    if (  ! m_rules->isSingleGroup(kbdLayout)
-	    		|| kbdLayout.startsWith("us") || kbdLayout.startsWith("en") ) {
-        widget->chkLatin->setEnabled( false );
-    }
-    else {
-		TQString inc = sel->text(LAYOUT_COLUMN_INCLUDE);
-		if ( inc.startsWith("us") || inc.startsWith("en") ) {
-            widget->chkLatin->setChecked(true);
-        }
-        else {
-            widget->chkLatin->setChecked(false);
-        }
-    }
-
 	TQStringList vars = m_rules->getAvailableVariants(kbdLayout);
 	kdDebug() << "layout " << kbdLayout << " has " << vars.count() << " variants" << endl;
 
@@ -623,12 +647,12 @@ TQWidget* LayoutConfig::makeOptionsTab()
   listView->clear();
 
   connect(listView, TQT_SIGNAL(clicked(TQListViewItem *)), TQT_SLOT(changed()));
-  connect(listView, TQT_SIGNAL(clicked(TQListViewItem *)), TQT_SLOT(updateOptionsCommand()));
+  connect(listView, TQT_SIGNAL(clicked(TQListViewItem *)), TQT_SLOT(resolveConflicts(TQListViewItem *)));
+  connect(listView, TQT_SIGNAL(clicked(TQListViewItem *)), TQT_SLOT(updateHotkeyCombo()));
 
-  connect(widget->chkEnableOptions, TQT_SIGNAL(toggled(bool)), TQT_SLOT(changed()));
-
-  connect(widget->checkResetOld, TQT_SIGNAL(toggled(bool)), TQT_SLOT(changed()));
-  connect(widget->checkResetOld, TQT_SIGNAL(toggled(bool)), TQT_SLOT(updateOptionsCommand()));
+  connect(widget->xkbOptsMode, TQT_SIGNAL(released(int)), TQT_SLOT(changed()));
+  connect(widget->xkbOptsMode, TQT_SIGNAL(released(int)), TQT_SLOT(updateOptionsCommand()));
+  connect(widget->xkbOptsMode, TQT_SIGNAL(released(int)), TQT_SLOT(updateHotkeyCombo()));
 
   //Create controllers for all options
   TQDictIterator<char> it(m_rules->options());
@@ -638,13 +662,20 @@ TQWidget* LayoutConfig::makeOptionsTab()
     if (!it.currentKey().contains(':'))
     {
       if( it.currentKey() == "ctrl" || it.currentKey() == "caps"
-          || it.currentKey() == "altwin" ) {
+          || it.currentKey() == "altwin") {
         parent = new OptionListItem(listView, i18n( it.current() ),
             TQCheckListItem::RadioButtonController, it.currentKey());
         OptionListItem *item = new OptionListItem(parent, i18n( "None" ),
             TQCheckListItem::RadioButton, "none");
         item->setState(TQCheckListItem::On);
       }
+      else if (it.currentKey() == "grp") {
+        parent = new OptionListItem(listView, i18n(it.current()),
+            TQCheckListItem::RadioButtonController, it.currentKey());
+        parent->setSelectable(false);
+        OptionListItem *item = new OptionListItem(parent, i18n("None"),
+            TQCheckListItem::CheckBox, "grp:none");
+      }
       else {
         parent = new OptionListItem(listView, i18n( it.current() ),
             TQCheckListItem::CheckBoxController, it.currentKey());
@@ -668,12 +699,13 @@ TQWidget* LayoutConfig::makeOptionsTab()
       // workaroung for mistake in rules file for xkb options in XFree 4.2.0
         TQString text(it.current());
         text = text.replace( "Cap$", "Caps." );
-        if( parent->type() == TQCheckListItem::RadioButtonController )
-            new OptionListItem(parent, i18n(text.utf8()),
-                TQCheckListItem::RadioButton, key);
-        else
+        if ( parent->type() == TQCheckListItem::CheckBoxController
+             || key.startsWith("grp:"))
             new OptionListItem(parent, i18n(text.utf8()),
                 TQCheckListItem::CheckBox, key);
+        else
+            new OptionListItem(parent, i18n(text.utf8()),
+                TQCheckListItem::RadioButton, key);
       }
     }
   }
@@ -687,64 +719,357 @@ void LayoutConfig::updateOptionsCommand()
 {
   TQString setxkbmap;
   TQString options = createOptionString();
+  bool overwrite = widget->radXkbOverwrite->isOn();
 
   if( !options.isEmpty() ) {
     setxkbmap = "setxkbmap -option "; //-rules " + m_rule
-    if( widget->checkResetOld->isChecked() )
+    if (overwrite)
       setxkbmap += "-option ";
     setxkbmap += options;
   }
+  else if (overwrite) {
+    setxkbmap = "setxkbmap -option";
+  }
   widget->editCmdLineOpt->setText(setxkbmap);
+  widget->editCmdLineOpt->setDisabled(setxkbmap.isEmpty());
 }
 
 void LayoutConfig::updateLayoutCommand()
 {
-  TQString setxkbmap;
-  TQString layoutDisplayName;
-  TQListViewItem* sel = widget->listLayoutsDst->selectedItem();
+  TQString setxkbmap = "setxkbmap";
+  setxkbmap += " -model " + lookupLocalized(m_rules->models(),
+                                            widget->comboModel->currentText());
+  TQStringList layoutCodes;
+  TQStringList layoutVariants;
+  TQListViewItem *item = widget->listLayoutsDst->firstChild();
+  while (item) {
+    layoutCodes << item->text(LAYOUT_COLUMN_MAP);
 
-  if( sel != NULL ) {
-    TQString kbdLayout = sel->text(LAYOUT_COLUMN_MAP);
-    TQString variant = widget->comboVariant->currentText();
-	if( variant == DEFAULT_VARIANT_NAME )
-		variant = "";
-
-    setxkbmap = "setxkbmap"; //-rules " + m_rule
-    setxkbmap += " -model " + lookupLocalized(m_rules->models(), widget->comboModel->currentText())
-      + " -layout ";
-    setxkbmap += kbdLayout;
-    if( widget->chkLatin->isChecked() )
-      setxkbmap += ",us";
-
-/*	LayoutUnit layoutUnitKey = getLayoutUnitKey(sel);
-	layoutDisplayName = m_kxkbConfig.getLayoutDisplayName( *m_kxkbConfig.m_layouts.find(layoutUnitKey) );*/
-	layoutDisplayName = sel->text(LAYOUT_COLUMN_DISPLAY_NAME);
-	if( layoutDisplayName.isEmpty() ) {
-		int count = 0;
-		TQListViewItem *item = widget->listLayoutsDst->firstChild();
-		while (item) {
-			TQString layout_ = item->text(LAYOUT_COLUMN_MAP);
-			if( layout_ == kbdLayout )
-				++count;
-			item = item->nextSibling();
-		}
-		bool single = count < 2;
-		layoutDisplayName = m_kxkbConfig.getDefaultDisplayName(LayoutUnit(kbdLayout, variant), single);
-	}
-	kdDebug() << "disp: '" << layoutDisplayName << "'" << endl;
-
-    if( !variant.isEmpty() ) {
-      setxkbmap += " -variant ";
-      if( widget->chkLatin->isChecked() )
-        setxkbmap += ",";
-      setxkbmap += variant;
+    TQString layoutVariant = item->text(LAYOUT_COLUMN_VARIANT);
+    if (layoutVariant == DEFAULT_VARIANT_NAME) {
+      layoutVariant = "";
     }
+    layoutVariants << layoutVariant;
+
+    item = item->nextSibling();
+  }
+
+  setxkbmap += " -layout " + layoutCodes.join(",");
+
+  if( !layoutVariants.isEmpty() ) {
+    setxkbmap += " -variant " + layoutVariants.join(",");
   }
 
   widget->editCmdLine->setText(setxkbmap);
 
+  /* update display name field */
+  TQListViewItem *sel = widget->listLayoutsDst->selectedItem();
+  if (!sel) {
+    return;
+  }
+  TQString selLayoutCode = sel->text(LAYOUT_COLUMN_MAP);
+  TQString selLayoutVariant = widget->comboVariant->currentText();
+  TQString selDisplayName = sel->text(LAYOUT_COLUMN_DISPLAY_NAME);
+  if (selDisplayName.isEmpty()) {
+    int count = 0;
+    TQListViewItem *item = widget->listLayoutsDst->firstChild();
+    while (item) {
+      TQString layoutCode_ = item->text(LAYOUT_COLUMN_MAP);
+      if (layoutCode_ == selLayoutCode) {
+        ++count;
+      }
+      item = item->nextSibling();
+    }
+    bool single = count < 2;
+    selDisplayName = m_kxkbConfig.getDefaultDisplayName(LayoutUnit(selLayoutCode, selLayoutVariant), single);
+  }
+
   widget->editDisplayName->setEnabled( sel != NULL );
-  widget->editDisplayName->setText(layoutDisplayName);
+  widget->editDisplayName->setText(selDisplayName);
+}
+
+void LayoutConfig::checkConflicts(OptionListItem *current,
+                                  TQStringList conflicting,
+                                  TQStringList &conflicts)
+{
+    if (!current || conflicting.count() < 2 ||
+        !conflicting.contains(current->optionName()))
+    {
+        return;
+    }
+    TQStringList::Iterator it;
+    for (it = conflicting.begin(); it != conflicting.end(); ++it) {
+        TQString option(*it);
+        if (option == current->optionName()) {
+            continue;
+        }
+
+        OptionListItem *item = itemForOption(option);
+        if (item && item->isOn()) {
+            conflicts << item->text();
+        }
+    }
+}
+
+void LayoutConfig::resolveConflicts(TQListViewItem *lvi) {
+    OptionListItem *current = (OptionListItem*)lvi;
+
+    kdDebug() << "resolveConflicts : " << current->optionName() << endl;
+
+    if (current->optionName().startsWith("grp:")) {
+        OptionListItem *grpItem = m_optionGroups[i18n("grp")];
+        if (grpItem == NULL) {
+            kdWarning() << "LayoutConfig: cannot find grp item group" << endl;
+            return;
+        }
+
+        OptionListItem *noneItem = grpItem->findChildItem("grp:none");
+        if (!noneItem) {
+            kdDebug() << "LayoutConfig: unable to find None item for grp!" << endl;
+        }
+        else {
+            // Option "none" selected, uncheck all other options immediately
+            if (current->optionName() == "grp:none") {
+                if (current->isOn()) {
+                    OptionListItem *child = (OptionListItem*)grpItem->firstChild();
+                    while (child) {
+                        if (child != current) {
+                            child->setOn(false);
+                        }
+                        child = (OptionListItem*)child->nextSibling();
+                    }
+                }
+                else {
+                    current->setOn(true);
+                }
+                updateOptionsCommand();
+                return;
+            }
+
+            // If no options are selected then select "none"
+            bool notNone = false;
+            OptionListItem *child = (OptionListItem*)grpItem->firstChild();
+            while (child) {
+                if (child->isOn() && child->optionName() != "none") {
+                    notNone = true;
+                    break;
+                }
+                child = (OptionListItem*)child->nextSibling();
+            }
+
+            noneItem->setOn(!notNone);
+        }
+    }
+
+    TQStringList conflicts;
+    OptionListItem *conflict;
+
+    TQStringList conflicting;
+    /* Might be incomplete */
+    // Space
+    conflicting << "grp:win_space_toggle"
+                << "grp:alt_space_toggle"
+                << "grp:ctrl_space_toggle";
+    checkConflicts(current, conflicting, conflicts);
+
+    // Shift
+    conflicting.clear();
+    conflicting << "grp:ctrl_shift_toggle"
+                << "grp:alt_shift_toggle";
+    checkConflicts(current, conflicting, conflicts);
+
+    // Control
+    conflicting.clear();
+    conflicting << "grp:ctrl_select"
+                << "grp:ctrl_alt_toggle"
+                << "grp:ctrl_shift_toggle";
+    checkConflicts(current, conflicting, conflicts);
+
+    // Left Ctrl
+    conflicting.clear();
+    conflicting << "grp:lctrl_toggle"
+                << "grp:lctrl_lshift_toggle";
+    checkConflicts(current, conflicting, conflicts);
+
+    // Right Ctrl
+    conflicting.clear();
+    conflicting << "grp:rctrl_toggle"
+                << "grp:rctrl_rshift_toggle";
+    checkConflicts(current, conflicting, conflicts);
+
+    // Win
+    conflicting.clear();
+    conflicting << "grp:win_space_toggle"
+                << "grp:win_switch"
+                << "win_menu_select";
+    checkConflicts(current, conflicting, conflicts);
+
+    // Left Alt
+    conflicting.clear();
+    conflicting << "grp:lalt_toggle"
+                << "grp:lalt_lshift_toggle";
+    checkConflicts(current, conflicting, conflicts);
+
+    // Right Alt
+    conflicting.clear();
+    conflicting << "grp:ralt_toggle"
+                << "grp:ralt_rshift_toggle";
+    checkConflicts(current, conflicting, conflicts);
+
+    // Caps Lock
+    conflicting.clear();
+    conflicting << "grp:caps_toggle"
+                << "grp:caps_select"
+                << "grp:caps_switch"
+                << "grp:alt_caps_toggle";
+    checkConflicts(current, conflicting, conflicts);
+
+    if (conflicts.count()) {
+        TQString curText = current->text();
+        int confirm = KMessageBox::warningYesNoList(this,
+                          i18n("<qt>The option <b>%1</b> might conflict with "
+                               "other options that you have already enabled.<br>"
+                               "Are you sure that you really want to enable "
+                               "<b>%2</b>?</qt>")
+                               .arg(curText).arg(curText),
+                          conflicts,
+                          i18n("Conflicting options"));
+        if (confirm == KMessageBox::No) {
+            current->setOn(false);
+        }
+    }
+    updateOptionsCommand();
+}
+
+// Synchronizes Xkb grp options --> hotkeys combobox
+void LayoutConfig::updateHotkeyCombo() {
+    updateHotkeyCombo(false);
+}
+
+void LayoutConfig::updateHotkeyCombo(bool initial) {
+    OptionListItem *grpItem = m_optionGroups[i18n("grp")];
+    if (grpItem == NULL) {
+        kdWarning() << "LayoutConfig: cannot find grp item group" << endl;
+        return;
+    }
+
+    TQStringList hotkeys;
+
+    // Get server options first
+    if (initial || widget->xkbOptsMode->selectedId() == 1)
+    {
+        TQStringList opts = TQStringList::split(",", XKBExtension::getServerOptions());
+        for (TQStringList::Iterator it = opts.begin(); it != opts.end(); ++it)
+        {
+            TQString option(*it);
+
+            if (!option.startsWith("grp:"))
+            {
+                continue;
+            }
+
+            // Get description from existing item
+            // This spares us the trouble of querying Xkb rules second time
+            OptionListItem *item = itemForOption(option);
+            if (!item)
+            {
+                kdWarning() << "[updateHotkeyCombo] server has set unknown option: "
+                            << option << endl;
+                continue;
+            }
+
+            TQString optionName = item->text();
+            if (!hotkeys.contains(optionName) && option != "grp:none")
+            {
+                hotkeys << optionName;
+            }
+        }
+    }
+
+    OptionListItem *child = (OptionListItem*)grpItem->firstChild();
+    while (child) {
+        TQString optionText = child->text();
+        if (child->isOn() && !hotkeys.contains(optionText) && child->optionName() != "grp:none") {
+            hotkeys << optionText;
+        }
+        child = (OptionListItem*)child->nextSibling();
+    }
+
+    if (!hotkeys.count()) {
+        OptionListItem *noneItem = itemForOption("grp:none");
+        if (noneItem)
+        {
+            hotkeys << noneItem->text();
+        }
+        else
+        {
+            kdWarning() << "[updateHotkeyCombo] cannot find grp:none item!" << endl;
+            hotkeys << widget->comboHotkey->text(0); // fallback
+        }
+    }
+
+    int other = widget->comboHotkey->count() - 1;
+    widget->comboHotkey->changeItem(i18n("Custom..."), other);
+    if (hotkeys.count() < 2) {
+        bool found = false;
+        for (int i = 0; i < widget->comboHotkey->count(); ++i) {
+            if (hotkeys[0] == widget->comboHotkey->text(i)) {
+                widget->comboHotkey->setCurrentItem(i);
+                found = true;
+            }
+        }
+        if (!found) {
+            widget->comboHotkey->changeItem(i18n("Other (%1)").arg(hotkeys[0]),
+                                            other);
+            widget->comboHotkey->setCurrentItem(other);
+        }
+    }
+    else {
+        widget->comboHotkey->changeItem(i18n("Multiple (%1)").arg(hotkeys.join("; ")),
+                                        other);
+        widget->comboHotkey->setCurrentItem(other);
+    }
+}
+
+// Synchronizes hotkeys combobox --> Xkb grp options
+void LayoutConfig::hotkeyComboChanged() {
+    TQStringList hotkeys;
+    int other = widget->comboHotkey->count() - 1;
+
+    if (widget->comboHotkey->currentItem() != other) {
+        hotkeys << widget->comboHotkey->currentText();
+    }
+    else {
+        TQString otherStr = widget->comboHotkey->text(other);
+        int i1 = otherStr.find("(");
+        if (i1 != -1) { // custom hotkey(s) set
+            ++i1;
+            int i2 = otherStr.findRev(")");
+            if (i2 != -1) {
+                hotkeys = TQStringList::split("; ", otherStr.mid(i1, i2-i1));
+            }
+        }
+    }
+
+    OptionListItem *grpItem = m_optionGroups[i18n("grp")];
+    if (grpItem == NULL) {
+        kdWarning() << "LayoutConfig: cannot find grp item group" << endl;
+        return;
+    }
+
+    OptionListItem *child = (OptionListItem*)grpItem->firstChild();
+    while (child) {
+        child->setOn(hotkeys.contains(child->text()));
+        child = (OptionListItem*)child->nextSibling();
+    }
+
+    if (widget->comboHotkey->currentItem() == other) {
+        widget->tabWidget->setCurrentPage(3);
+        widget->listOptions->ensureItemVisible(grpItem);
+        widget->listOptions->setFocus();
+    }
+
+    m_forceGrpOverwrite = true;
 }
 
 void LayoutConfig::changed()
@@ -794,6 +1119,20 @@ void LayoutConfig::loadRules()
 	//TODO: reset options and xkb options
 }
 
+OptionListItem* LayoutConfig::itemForOption(TQString option) {
+    if (!option.contains(':')) {
+        return nullptr;
+    }
+
+    TQString optionKey = option.mid(0, option.find(':'));
+    OptionListItem *item = m_optionGroups[optionKey];
+
+    if( !item ) {
+        kdDebug() << "WARNING: skipping empty group for " << option << endl;
+        return nullptr;
+    }
+    return (OptionListItem*)item->findChildItem(option);
+}
 
 TQString LayoutConfig::createOptionString()
 {
@@ -801,32 +1140,17 @@ TQString LayoutConfig::createOptionString()
   for (TQDictIterator<char> it(m_rules->options()); it.current(); ++it)
   {
     TQString option(it.currentKey());
-
-    if (option.contains(':')) {
-
-      TQString optionKey = option.mid(0, option.find(':'));
-      OptionListItem *item = m_optionGroups[optionKey];
-
-      if( !item ) {
-        kdDebug() << "WARNING: skipping empty group for " << it.currentKey()
-          << endl;
-        continue;
+    OptionListItem *child = itemForOption(option);
+    if (!child) {
+      continue;
+    }
+    if ( child->state() == TQCheckListItem::On ) {
+      TQString selectedName = child->optionName();
+      if ( !selectedName.isEmpty() && selectedName != "none" ) {
+        if (!options.isEmpty())
+          options.append(',');
+        options.append(selectedName);
       }
-
-      OptionListItem *child = item->findChildItem( option );
-
-      if ( child ) {
-        if ( child->state() == TQCheckListItem::On ) {
-          TQString selectedName = child->optionName();
-          if ( !selectedName.isEmpty() && selectedName != "none" ) {
-            if (!options.isEmpty())
-              options.append(',');
-            options.append(selectedName);
-          }
-        }
-      }
-      else
-        kdDebug() << "Empty option button for group " << it.currentKey() << endl;
     }
   }
   return options;
@@ -894,12 +1218,8 @@ extern "C"
 			kapp->startServiceByDesktopName("kxkb");
 		}
 		else {
-		// Even if the layouts have been disabled we still want to set Xkb options
-		// user can always switch them off now in the "Options" tab
-			if( m_kxkbConfig.m_enableXkbOptions ) {
-				if( !XKBExtension::setXkbOptions(m_kxkbConfig.m_options, m_kxkbConfig.m_resetOldOptions) ) {
-					kdDebug() << "Setting XKB options failed!" << endl;
-				}
+			if (!XKBExtension::setXkbOptions(m_kxkbConfig.getKXkbOptions())) {
+				kdDebug() << "Setting XKB options failed!" << endl;
 			}
 		}
 	}
