@@ -80,7 +80,7 @@
 #include <tqdir.h>
 #include <tqtextstream.h>
 
-#include <tdepimmacros.h>
+#include <kdemacros.h>
 
 #include <dcopclient.h>
 #include <dcopref.h>
