@@ -1574,7 +1574,7 @@ void marshall_TQMapTQStringTQVariant(Marshall *m) {
 		break;
 	    }
 		
-		TQMap<TQString,TQVariant> * map = new TQMap<TQString,TQVariant>;
+		TQStringVariantMap * map = new TQStringVariantMap;
 		
 		// Convert the ruby hash to an array of key/value arrays
 		VALUE temp = rb_funcall(hash, rb_intern("to_a"), 0);
@@ -1609,7 +1609,7 @@ void marshall_TQMapTQStringTQVariant(Marshall *m) {
 	break;
       case Marshall::ToVALUE:
 	{
-	    TQMap<TQString,TQVariant> *map = (TQMap<TQString,TQVariant>*)m->item().s_voidp;
+	    TQStringVariantMap *map = (TQStringVariantMap*)m->item().s_voidp;
 	    if(!map) {
 		*(m->var()) = Qnil;
 		break;
@@ -1617,7 +1617,7 @@ void marshall_TQMapTQStringTQVariant(Marshall *m) {
 		
 	    VALUE hv = rb_hash_new();
 			
-		TQMap<TQString,TQVariant>::Iterator it;
+		TQStringVariantMap::Iterator it;
 		for (it = map->begin(); it != map->end(); ++it) {
 			void *p = new TQVariant(it.data());
 			VALUE obj = getPointerObject(p);
@@ -1942,8 +1942,8 @@ TypeHandler Qt_handlers[] = {
     { "TQCanvasItemList", marshall_TQCanvasItemList },
     { "TQMap<TQString,TQString>", marshall_TQMapTQStringTQString },
     { "TQMap<TQString,TQString>&", marshall_TQMapTQStringTQString },
-    { "TQMap<TQString,TQVariant>", marshall_TQMapTQStringTQVariant },
-    { "TQMap<TQString,TQVariant>&", marshall_TQMapTQStringTQVariant },
+    { "TQStringVariantMap", marshall_TQMapTQStringTQVariant },
+    { "TQStringVariantMap&", marshall_TQMapTQStringTQVariant },
 #if TQT_VERSION >= 0x030200
     { "TQWidgetList", marshall_TQWidgetList },
     { "TQWidgetList*", marshall_TQWidgetList },
