@@ -318,7 +318,7 @@ namespace Qt {
 
 		private static TQEventList eventList = new TQEventList ();
 
-		[DllImport("libqtsharp", CharSet=CharSet.Ansi)]
+		[DllImport("libtqtsharp", CharSet=CharSet.Ansi)]
 	        private static extern void qtsharp_QObject_registerEventDelegate
 			([MarshalAs (UnmanagedType.FunctionPtr)] Delegate qtdelegate);
 
