@@ -12,7 +12,7 @@
 **********************************************************************/
 
 #include "qttableview.h"
-#ifndef QT_NO_QTTABLEVIEW
+#ifndef TQT_NO_QTTABLEVIEW
 #include "ntqscrollbar.h"
 #include "ntqpainter.h"
 #include "ntqdrawutil.h"
@@ -1313,7 +1313,7 @@ void TQtTableView::paintEvent( TQPaintEvent *e )
     TQRect winR = viewRect();
     TQRect cellR;
     TQRect cellUR;
-#ifndef QT_NO_TRANSFORMATIONS
+#ifndef TQT_NO_TRANSFORMATIONS
     TQWMatrix matrix;
 #endif
 
@@ -1337,7 +1337,7 @@ void TQtTableView::paintEvent( TQPaintEvent *e )
 		if ( eraseInPaint )
 		    paint.eraseRect( cellUR );
 
-#ifndef QT_NO_TRANSFORMATIONS
+#ifndef TQT_NO_TRANSFORMATIONS
 		matrix.translate( xPos, yPos );
 		paint.setWorldMatrix( matrix );
 		if ( testTableFlags(Tbl_clipCellPainting) ||
@@ -1438,7 +1438,7 @@ TQScrollBar *TQtTableView::verticalScrollBar() const
     TQtTableView *that = (TQtTableView*)this; // semantic const
     if ( !vScrollBar ) {
 	TQScrollBar *sb = new TQScrollBar( TQScrollBar::Vertical, that );
-#ifndef QT_NO_CURSOR
+#ifndef TQT_NO_CURSOR
 	sb->setCursor( arrowCursor );
 #endif
         sb->resize( sb->sizeHint() ); // height is irrelevant
@@ -1469,7 +1469,7 @@ TQScrollBar *TQtTableView::horizontalScrollBar() const
     TQtTableView *that = (TQtTableView*)this; // semantic const
     if ( !hScrollBar ) {
 	TQScrollBar *sb = new TQScrollBar( TQScrollBar::Horizontal, that );
-#ifndef QT_NO_CURSOR
+#ifndef TQT_NO_CURSOR
 	sb->setCursor( arrowCursor );
 #endif
 	sb->resize( sb->sizeHint() ); // width is irrelevant
