@@ -40,7 +40,7 @@
 
 #include "ntqmessagebox.h"
 
-#ifndef QT_NO_MESSAGEBOX
+#ifndef TQT_NO_MESSAGEBOX
 
 #include "ntqaccel.h"
 #include "ntqlabel.h"
@@ -54,7 +54,7 @@
 #endif
 
 #ifdef Q_WS_X11
-#include "private/qtkdeintegration_x11_p.h"
+#include "private/tqttdeintegration_x11_p.h"
 #endif
 
 extern bool tqt_use_native_dialogs;
@@ -562,7 +562,7 @@ TQMessageBox::TQMessageBox( const TQString& caption,
     : TQDialog( parent, name, modal, f | WStyle_Customize | WStyle_DialogBorder | WStyle_Title | WStyle_SysMenu )
 {
     init( button0, button1, button2 );
-#ifndef QT_NO_WIDGET_TOPEXTRA
+#ifndef TQT_NO_WIDGET_TOPEXTRA
     setCaption( caption );
 #endif
     setText( text );
@@ -1014,7 +1014,7 @@ void TQMessageBox::keyPressEvent( TQKeyEvent *e )
             return;
         }
     }
-#ifndef QT_NO_ACCEL
+#ifndef TQT_NO_ACCEL
     if ( !( e->state() & AltButton ) ) {
 	TQObjectList *list = queryList( "TQPushButton" );
 	TQObjectListIt it( *list );
@@ -1113,8 +1113,8 @@ int TQMessageBox::information( TQWidget *parent,
                               int button0, int button1, int button2 )
 {
 #if defined(Q_WS_X11)
-    if ( tqt_use_native_dialogs && TQKDEIntegration::enabled())
-        return TQKDEIntegration::information( parent, caption, text, button0, button1, button2 );
+    if ( tqt_use_native_dialogs && TQTDEIntegration::enabled())
+        return TQTDEIntegration::information( parent, caption, text, button0, button1, button2 );
 #endif
     TQMessageBox *mb = new TQMessageBox( caption, text, Information,
                                        button0, button1, button2,
@@ -1164,8 +1164,8 @@ int TQMessageBox::question( TQWidget *parent,
                            int button0, int button1, int button2 )
 {
 #if defined(Q_WS_X11)
-    if ( tqt_use_native_dialogs && TQKDEIntegration::enabled())
-        return TQKDEIntegration::question( parent, caption, text, button0, button1, button2 );
+    if ( tqt_use_native_dialogs && TQTDEIntegration::enabled())
+        return TQTDEIntegration::question( parent, caption, text, button0, button1, button2 );
 #endif
     TQMessageBox *mb = new TQMessageBox( caption, text, Question,
                                        button0, button1, button2,
@@ -1216,8 +1216,8 @@ int TQMessageBox::warning( TQWidget *parent,
                           int button0, int button1, int button2 )
 {
 #if defined(Q_WS_X11)
-    if ( tqt_use_native_dialogs && TQKDEIntegration::enabled())
-        return TQKDEIntegration::warning( parent, caption, text, button0, button1, button2 );
+    if ( tqt_use_native_dialogs && TQTDEIntegration::enabled())
+        return TQTDEIntegration::warning( parent, caption, text, button0, button1, button2 );
 #endif
     TQMessageBox *mb = new TQMessageBox( caption, text, Warning,
                                        button0, button1, button2,
@@ -1268,8 +1268,8 @@ int TQMessageBox::critical( TQWidget *parent,
                            int button0, int button1, int button2 )
 {
 #if defined(Q_WS_X11)
-    if ( tqt_use_native_dialogs && TQKDEIntegration::enabled())
-        return TQKDEIntegration::critical( parent, caption, text, button0, button1, button2 );
+    if ( tqt_use_native_dialogs && TQTDEIntegration::enabled())
+        return TQTDEIntegration::critical( parent, caption, text, button0, button1, button2 );
 #endif
     TQMessageBox *mb = new TQMessageBox( caption, text, Critical,
                                        button0, button1, button2,
@@ -1307,7 +1307,7 @@ void TQMessageBox::about( TQWidget *parent, const TQString &caption,
                                        parent, "qt_msgbox_simple_about_box", TRUE,
 				       WDestructiveClose);
     TQ_CHECK_PTR( mb );
-#ifndef QT_NO_WIDGET_TOPEXTRA
+#ifndef TQT_NO_WIDGET_TOPEXTRA
     const TQPixmap *pm = parent ? parent->icon() : 0;
     if ( pm && !pm->isNull() )
 	mb->setIconPixmap( *pm );
@@ -1373,7 +1373,7 @@ static int textBox( TQWidget *parent, TQMessageBox::Icon severity,
     if ( b[2] )
         mb->setButtonText( 3, button2Text );
 
-#ifndef QT_NO_CURSOR
+#ifndef TQT_NO_CURSOR
     mb->setCursor( TQt::arrowCursor );
 #endif
     return mb->exec() - 1;
@@ -1419,8 +1419,8 @@ int TQMessageBox::information( TQWidget *parent, const TQString &caption,
                               int escapeButtonNumber )
 {
 #if defined(Q_WS_X11)
-    if ( tqt_use_native_dialogs && TQKDEIntegration::enabled())
-        return TQKDEIntegration::information( parent, caption, text,
+    if ( tqt_use_native_dialogs && TQTDEIntegration::enabled())
+        return TQTDEIntegration::information( parent, caption, text,
             button0Text, button1Text, button2Text, defaultButtonNumber, escapeButtonNumber );
 #endif
     return textBox( parent, Information, caption, text,
@@ -1466,8 +1466,8 @@ int TQMessageBox::question( TQWidget *parent, const TQString &caption,
                            int escapeButtonNumber )
 {
 #if defined(Q_WS_X11)
-    if ( tqt_use_native_dialogs && TQKDEIntegration::enabled())
-        return TQKDEIntegration::question( parent, caption, text,
+    if ( tqt_use_native_dialogs && TQTDEIntegration::enabled())
+        return TQTDEIntegration::question( parent, caption, text,
             button0Text, button1Text, button2Text, defaultButtonNumber, escapeButtonNumber );
 #endif
     return textBox( parent, Question, caption, text,
@@ -1515,8 +1515,8 @@ int TQMessageBox::warning( TQWidget *parent, const TQString &caption,
                                  int escapeButtonNumber )
 {
 #if defined(Q_WS_X11)
-    if ( tqt_use_native_dialogs && TQKDEIntegration::enabled())
-        return TQKDEIntegration::warning( parent, caption, text,
+    if ( tqt_use_native_dialogs && TQTDEIntegration::enabled())
+        return TQTDEIntegration::warning( parent, caption, text,
             button0Text, button1Text, button2Text, defaultButtonNumber, escapeButtonNumber );
 #endif
     return textBox( parent, Warning, caption, text,
@@ -1560,8 +1560,8 @@ int TQMessageBox::critical( TQWidget *parent, const TQString &caption,
                                   int escapeButtonNumber )
 {
 #if defined(Q_WS_X11)
-    if ( tqt_use_native_dialogs && TQKDEIntegration::enabled())
-        return TQKDEIntegration::critical( parent, caption, text,
+    if ( tqt_use_native_dialogs && TQTDEIntegration::enabled())
+        return TQTDEIntegration::critical( parent, caption, text,
             button0Text, button1Text, button2Text, defaultButtonNumber, escapeButtonNumber );
 #endif
     return textBox( parent, Critical, caption, text,
@@ -1589,14 +1589,14 @@ void TQMessageBox::aboutTQt( TQWidget *parent, const TQString &caption )
     TQ_CHECK_PTR( mb );
     mb->setWFlags( WDestructiveClose );
 
-#ifndef QT_NO_WIDGET_TOPEXTRA
+#ifndef TQT_NO_WIDGET_TOPEXTRA
     TQString c = caption;
     if ( c.isNull() )
         c = tr( "About TQt" );
     mb->setCaption( c );
 #endif
     mb->setText( *translatedTextAboutTQt );
-#ifndef QT_NO_IMAGEIO
+#ifndef TQT_NO_IMAGEIO
     TQPixmap pm;
     TQImage logo( (const char **)qtlogo_xpm);
     if ( tqGray(mb->palette().active().text().rgb()) >
@@ -1633,7 +1633,7 @@ void TQMessageBox::aboutTQt( TQWidget *parent, const TQString &caption )
 void TQMessageBox::setIcon( const TQPixmap &pix )
 {
     //reimplemented to avoid compiler warning.
-#ifndef QT_NO_WIDGET_TOPEXTRA
+#ifndef TQT_NO_WIDGET_TOPEXTRA
     TQDialog::setIcon( pix );
 #endif
 }
