@@ -40,7 +40,7 @@
 
 #include "ntqtabdialog.h"
 
-#ifndef QT_NO_TABDIALOG
+#ifndef TQT_NO_TABDIALOG
 
 #include "ntqobjectlist.h"
 #include "ntqtabbar.h"
