@@ -62,7 +62,7 @@
 
 #include "ntqclipboard.h"
 
-#ifndef QT_NO_CLIPBOARD
+#ifndef TQT_NO_CLIPBOARD
 
 #include "ntqapplication.h"
 #include "ntqeventloop.h"
@@ -1670,4 +1670,4 @@ bool qt_check_clipboard_sentinel()
     return doIt;
 }
 
-#endif // QT_NO_CLIPBOARD
+#endif // TQT_NO_CLIPBOARD
