@@ -40,7 +40,7 @@
 
 #include "ntqfontdatabase.h"
 
-#ifndef QT_NO_FONTDATABASE
+#ifndef TQT_NO_FONTDATABASE
 
 #include <ntqtl.h>
 #include <ntqapplication.h>
@@ -601,7 +601,7 @@ static const unsigned short sample_chars[TQFont::LastPrivateScript][14] =
     // Taiwan would be 0x201C, 0x3002, 0x4E00, 0x9F98, 0xFFE5
 };
 
-#if defined(Q_WS_X11) && !defined(QT_NO_XFTFREETYPE)
+#if defined(Q_WS_X11) && !defined(TQT_NO_XFTFREETYPE)
 static inline bool requiresOpenType(TQFont::Script s)
 {
     return (s >= TQFont::Syriac && s <= TQFont::Sinhala)
@@ -631,7 +631,7 @@ static inline bool canRender( TQFontEngine *fe, TQFont::Script script )
         }
         ++i;
     }
-#if defined(Q_WS_X11) && !defined(QT_NO_XFTFREETYPE)
+#if defined(Q_WS_X11) && !defined(TQT_NO_XFTFREETYPE)
     if (hasChar && requiresOpenType(script)) {
 	TQOpenType *ot = fe->openType();
 	if (!ot || !ot->supportsScript(script))
@@ -2488,4 +2488,4 @@ void TQFontDatabase::parseFontName(const TQString &name, TQString &foundry, TQSt
     }
 }
 
-#endif // QT_NO_FONTDATABASE
+#endif // TQT_NO_FONTDATABASE
