@@ -40,7 +40,7 @@
 
 #include "ntqnetworkprotocol.h"
 
-#ifndef QT_NO_NETWORKPROTOCOL
+#ifndef TQT_NO_NETWORKPROTOCOL
 
 #include "ntqlocalfs.h"
 #include "ntqurloperator.h"
