@@ -49,7 +49,7 @@ static inline int qt_open(const char *pathname, int flags, mode_t mode)
 
 #include "ntqprinter.h"
 
-#ifndef QT_NO_PRINTER
+#ifndef TQT_NO_PRINTER
 
 #include "ntqpaintdevicemetrics.h"
 #include "qpsprinter_p.h"
@@ -250,7 +250,7 @@ static void deleteGlobalPrinterDefaults()
 
 bool TQPrinter::setup( TQWidget * parent )
 {
-#ifndef QT_NO_PRINTDIALOG
+#ifndef TQT_NO_PRINTDIALOG
     bool result = TQPrintDialog::getPrinterSetup( this, parent  );
 #else
     bool result = FALSE;
