@@ -36,7 +36,7 @@
 **
 **********************************************************************/
 
-#if defined(QT_THREAD_SUPPORT)
+#if defined(TQT_THREAD_SUPPORT)
 
 #include "qplatformdefs.h"
 
@@ -561,4 +561,4 @@ TQThread *TQThread::currentThreadObject()
 }
 
 
-#endif // QT_THREAD_SUPPORT
+#endif // TQT_THREAD_SUPPORT
