@@ -40,7 +40,7 @@
 
 #include "ntqftp.h"
 
-#ifndef QT_NO_NETWORKPROTOCOL_FTP
+#ifndef TQT_NO_NETWORKPROTOCOL_FTP
 
 #include "ntqsocket.h"
 #include "ntqsocketdevice.h"
@@ -52,7 +52,7 @@
 #include "ntqfileinfo.h"
 #include "ntqptrdict.h" // binary compatibility
 
-#ifndef QT_NO_TEXTCODEC
+#ifndef TQT_NO_TEXTCODEC
 #include "ntqtextcodec.h"
 #endif
 
@@ -935,7 +935,7 @@ bool TQFtpPI::processReply()
     return TRUE;
 }
 
-#ifndef QT_NO_TEXTCODEC
+#ifndef TQT_NO_TEXTCODEC
 TQM_EXPORT_FTP TQTextCodec *tqt_ftp_filename_codec = 0;
 #endif
 
@@ -964,7 +964,7 @@ bool TQFtpPI::startNextCmd()
     tqDebug( "TQFtpPI send: %s", currentCmd.left( currentCmd.length()-2 ).latin1() );
 #endif
     state = Waiting;
-#ifndef QT_NO_TEXTCODEC
+#ifndef TQT_NO_TEXTCODEC
     if ( tqt_ftp_filename_codec ) {
 	int len = 0;
 	TQCString enc = tqt_ftp_filename_codec->fromUnicode(currentCmd,len);
@@ -2416,4 +2416,4 @@ void TQFtp::error( int )
 
 #include "qftp.moc"
 
-#endif // QT_NO_NETWORKPROTOCOL_FTP
+#endif // TQT_NO_NETWORKPROTOCOL_FTP
