@@ -40,7 +40,7 @@
 
 #include "ntqhttp.h"
 
-#ifndef QT_NO_NETWORKPROTOCOL_HTTP
+#ifndef TQT_NO_NETWORKPROTOCOL_HTTP
 
 #include "ntqsocket.h"
 #include "ntqtextstream.h"
