@@ -40,7 +40,7 @@
 
 #include "ntqdatetimeedit.h"
 
-#ifndef QT_NO_DATETIMEEDIT
+#ifndef TQT_NO_DATETIMEEDIT
 
 #include "../kernel/qinternal_p.h"
 #include "../kernel/qrichtext_p.h"
@@ -434,7 +434,7 @@ public:
     }
 
 protected:
-#ifndef QT_NO_WHEELEVENT
+#ifndef TQT_NO_WHEELEVENT
     void wheelEvent( TQWheelEvent *e )
     {
 	TQDateTimeEditor *editor = (TQDateTimeEditor*)editWidget()->tqt_cast( "TQDateTimeEditor" );
