@@ -39,7 +39,7 @@
 **********************************************************************/
 
 #include "ntqmainwindow.h"
-#ifndef QT_NO_MAINWINDOW
+#ifndef TQT_NO_MAINWINDOW
 
 #include "ntqtimer.h"
 #include "ntqlayout.h"
@@ -88,7 +88,7 @@ public:
     {
     }
 
-#ifndef QT_NO_MENUBAR
+#ifndef TQT_NO_MENUBAR
     TQMenuBar * mb;
 #else
     TQWidget * mb;
@@ -285,7 +285,7 @@ TQLayoutIterator TQMainWindowLayout::iterator()
   TQHideToolTip and TQHideDock - minimized dock
 */
 
-#ifndef QT_NO_TOOLTIP
+#ifndef TQT_NO_TOOLTIP
 class TQHideToolTip : public TQToolTip
 {
 public:
@@ -310,13 +310,13 @@ public:
 	pressed = FALSE;
 	setMouseTracking( TRUE );
 	win = parent;
-#ifndef QT_NO_TOOLTIP
+#ifndef TQT_NO_TOOLTIP
 	tip = new TQHideToolTip( this );
 #endif
     }
     ~TQHideDock()
     {
-#ifndef QT_NO_TOOLTIP
+#ifndef TQT_NO_TOOLTIP
 	delete tip;
 #endif
     }
@@ -471,13 +471,13 @@ private:
     TQMainWindow *win;
     int pressedHandle;
     bool pressed;
-#ifndef QT_NO_TOOLTIP
+#ifndef TQT_NO_TOOLTIP
     TQHideToolTip *tip;
     friend class TQHideToolTip;
 #endif
 };
 
-#ifndef QT_NO_TOOLTIP
+#ifndef TQT_NO_TOOLTIP
 void TQHideToolTip::maybeTip( const TQPoint &pos )
 {
     if ( !parentWidget() )
@@ -921,7 +921,7 @@ TQMainWindow::~TQMainWindow()
     delete d;
 }
 
-#ifndef QT_NO_MENUBAR
+#ifndef TQT_NO_MENUBAR
 /*!
     Sets this main window to use the menu bar \a newMenuBar.
 
@@ -970,7 +970,7 @@ TQMenuBar * TQMainWindow::menuBar() const
     ((TQMainWindow *)this)->triggerLayout();
     return b;
 }
-#endif // QT_NO_MENUBAR
+#endif // TQT_NO_MENUBAR
 
 /*!
     Sets this main window to use the status bar \a newStatusBar.
@@ -993,7 +993,7 @@ void TQMainWindow::setStatusBar( TQStatusBar * newStatusBar )
     if ( d->sb )
 	delete d->sb;
     d->sb = newStatusBar;
-#ifndef QT_NO_TOOLTIP
+#ifndef TQT_NO_TOOLTIP
     // ### this code can cause unnecessary creation of a tool tip group
     connect( toolTipGroup(), SIGNAL(showTip(const TQString&)),
 	     d->sb, SLOT(message(const TQString&)) );
@@ -1034,7 +1034,7 @@ TQStatusBar * TQMainWindow::statusBar() const
 }
 
 
-#ifndef QT_NO_TOOLTIP
+#ifndef TQT_NO_TOOLTIP
 /*!
     Sets this main window to use the tool tip group \a
     newToolTipGroup.
@@ -1275,7 +1275,7 @@ void TQMainWindow::addDockWindow( TQDockWindow * dockWindow, const TQString &lab
 			      Dock edge, bool newLine )
 {
     addDockWindow( dockWindow, edge, newLine );
-#ifndef QT_NO_TOOLBAR
+#ifndef TQT_NO_TOOLBAR
     TQToolBar *tb = ::tqt_cast<TQToolBar*>(dockWindow);
     if ( tb )
 	tb->setLabel( label );
@@ -1426,7 +1426,7 @@ void TQMainWindow::removeDockWindow( TQDockWindow * dockWindow )
 
 void TQMainWindow::setUpLayout()
 {
-#ifndef QT_NO_MENUBAR
+#ifndef TQT_NO_MENUBAR
     if ( !d->mb ) {
 	// slightly evil hack here.  reconsider this
 	TQObjectList * l
@@ -1456,7 +1456,7 @@ void TQMainWindow::setUpLayout()
 	    delete item;
     }
 
-#ifndef QT_NO_MENUBAR
+#ifndef TQT_NO_MENUBAR
     if ( d->mb && d->mb->isVisibleTo( this ) ) {
 	d->tll->setMenuBar( d->mb );
 	if (style().styleHint(TQStyle::SH_MainWindow_SpaceBelowMenuBar, this))
@@ -1851,7 +1851,7 @@ void TQMainWindow::triggerLayout( bool deleteLayout )
 */
 void TQMainWindow::whatsThis()
 {
-#ifndef QT_NO_WHATSTHIS
+#ifndef TQT_NO_WHATSTHIS
     TQWhatsThis::enterWhatsThisMode();
 #endif
 }
@@ -1907,7 +1907,7 @@ bool TQMainWindow::getLocation( TQDockWindow *dw, Dock &dock, int &index, bool &
     return TRUE;
 }
 
-#ifndef QT_NO_TOOLBAR
+#ifndef TQT_NO_TOOLBAR
 /*!
     Returns a list of all the toolbars which are in the \a dock dock
     area, regardless of their state.
@@ -2214,7 +2214,7 @@ void TQMainWindow::menuAboutToShow()
 
 	empty = TRUE;
 
-#ifndef QT_NO_TOOLBAR
+#ifndef TQT_NO_TOOLBAR
 	if ( dockWindows == AllDockWindows || dockWindows == OnlyToolBars ) {
 	    for ( o = l->first(); o; o = l->next() ) {
 		TQToolBar *tb = ::tqt_cast<TQToolBar*>(o);
@@ -2280,7 +2280,7 @@ void TQMainWindow::slotPlaceChanged()
     TQDockWindow *dw = ::tqt_cast<TQDockWindow*>(obj);
     if ( dw )
 	emit dockWindowPositionChanged( dw );
-#ifndef QT_NO_TOOLBAR
+#ifndef TQT_NO_TOOLBAR
     TQToolBar *tb = ::tqt_cast<TQToolBar*>(obj);
     if ( tb )
 	emit toolBarPositionChanged( tb );
@@ -2442,7 +2442,7 @@ void TQMainWindow::setAppropriate( TQDockWindow *dw, bool a )
     d->appropriate.replace( dw, a );
 }
 
-#ifndef QT_NO_TEXTSTREAM
+#ifndef TQT_NO_TEXTSTREAM
 static void saveDockArea( TQTextStream &ts, TQDockArea *a )
 {
     TQPtrList<TQDockWindow> l = a->dockWindowList();
