@@ -39,7 +39,7 @@
 **********************************************************************/
 
 #include "ntqtabwidget.h"
-#ifndef QT_NO_TABWIDGET
+#ifndef TQT_NO_TABWIDGET
 #include "ntqobjectlist.h"
 #include "ntqtabbar.h"
 #include "ntqapplication.h"
