@@ -37,7 +37,7 @@
 **********************************************************************/
 
 #include "ntqtooltip.h"
-#ifndef QT_NO_TOOLTIP
+#ifndef TQT_NO_TOOLTIP
 #include "ntqlabel.h"
 #include "ntqptrdict.h"
 #include "ntqapplication.h"
@@ -570,7 +570,7 @@ void TQTipManager::showTip()
     if ( label->text().length() ) {
 	label->move( p );
 
-#ifndef QT_NO_EFFECTS
+#ifndef TQT_NO_EFFECTS
 	if ( TQApplication::isEffectEnabled( UI_AnimateTooltip ) == FALSE ||
 	     previousTip || preventAnimation )
 	    label->show();
