@@ -37,7 +37,7 @@
 **********************************************************************/
 
 #include "ntqwhatsthis.h"
-#ifndef QT_NO_WHATSTHIS
+#ifndef TQT_NO_WHATSTHIS
 #include "ntqapplication.h"
 #include "ntqpaintdevicemetrics.h"
 #include "ntqpixmap.h"
@@ -163,7 +163,7 @@ protected:
 
 private:
     TQString text;
-#ifndef QT_NO_RICHTEXT
+#ifndef TQT_NO_RICHTEXT
     TQSimpleRichText* doc;
 #endif
     TQString anchor;
@@ -247,7 +247,7 @@ TQWhatsThat::TQWhatsThat( TQWidget* w, const TQString& txt, TQWidget* parent, co
     setBackgroundMode( NoBackground );
     setPalette( TQToolTip::palette() );
     setMouseTracking( TRUE );
-#ifndef QT_NO_CURSOR
+#ifndef TQT_NO_CURSOR
     setCursor( arrowCursor );
 #endif
 
@@ -256,7 +256,7 @@ TQWhatsThat::TQWhatsThat( TQWidget* w, const TQString& txt, TQWidget* parent, co
 
 
     TQRect r;
-#ifndef QT_NO_RICHTEXT
+#ifndef TQT_NO_RICHTEXT
     doc = 0;
     if ( TQStyleSheet::mightBeRichText( text ) ) {
 	TQFont f = TQApplication::font( this );
@@ -291,7 +291,7 @@ TQWhatsThat::~TQWhatsThat()
 {
     if ( wt && wt->whatsThat == this )
 	wt->whatsThat = 0;
-#ifndef QT_NO_RICHTEXT
+#ifndef TQT_NO_RICHTEXT
     if ( doc )
 	delete doc;
 #endif
@@ -309,7 +309,7 @@ void TQWhatsThat::mousePressEvent( TQMouseEvent* e )
 {
     pressed = TRUE;
     if ( e->button() == LeftButton && rect().contains( e->pos() ) ) {
-#ifndef QT_NO_RICHTEXT
+#ifndef TQT_NO_RICHTEXT
 	if ( doc )
 	    anchor = doc->anchorAt( e->pos() -  TQPoint( hMargin, vMargin) );
 #endif
@@ -322,7 +322,7 @@ void TQWhatsThat::mouseReleaseEvent( TQMouseEvent* e )
 {
     if ( !pressed )
 	return;
-#ifndef QT_NO_RICHTEXT
+#ifndef TQT_NO_RICHTEXT
     if ( e->button() == LeftButton && doc && rect().contains( e->pos() ) ) {
 	TQString a = doc->anchorAt( e->pos() -  TQPoint( hMargin, vMargin ) );
 	TQString href;
@@ -341,8 +341,8 @@ void TQWhatsThat::mouseReleaseEvent( TQMouseEvent* e )
 
 void TQWhatsThat::mouseMoveEvent( TQMouseEvent* e)
 {
-#ifndef QT_NO_RICHTEXT
-#ifndef QT_NO_CURSOR
+#ifndef TQT_NO_RICHTEXT
+#ifndef TQT_NO_CURSOR
     if ( !doc )
 	return;
     TQString a = doc->anchorAt( e->pos() -  TQPoint( hMargin, vMargin ) );
@@ -402,7 +402,7 @@ void TQWhatsThat::paintEvent( TQPaintEvent* )
     p.setPen( colorGroup().foreground() );
     r.addCoords( hMargin, vMargin, -hMargin, -vMargin );
 
-#ifndef QT_NO_RICHTEXT
+#ifndef TQT_NO_RICHTEXT
     if ( doc ) {
 	doc->draw( &p, r.x(), r.y(), r, colorGroup(), 0 );
     }
@@ -471,7 +471,7 @@ void TQWhatsThisButton::mouseReleased()
 {
     if ( wt->state == TQWhatsThisPrivate::Inactive && isOn() ) {
 	TQWhatsThisPrivate::setUpWhatsThis();
-#ifndef QT_NO_CURSOR
+#ifndef TQT_NO_CURSOR
 	TQApplication::setOverrideCursor( whatsThisCursor, FALSE );
 #endif
 	wt->state = TQWhatsThisPrivate::Waiting;
@@ -501,7 +501,7 @@ TQWhatsThisPrivate::TQWhatsThisPrivate()
 
 TQWhatsThisPrivate::~TQWhatsThisPrivate()
 {
-#ifndef QT_NO_CURSOR
+#ifndef TQT_NO_CURSOR
     if ( state == Waiting && tqApp )
 	TQApplication::restoreOverrideCursor();
 #endif
@@ -639,7 +639,7 @@ void TQWhatsThisPrivate::leaveWhatsThisMode()
 	    ++it;
 	    b->setOn( FALSE );
 	}
-#ifndef QT_NO_CURSOR
+#ifndef TQT_NO_CURSOR
 	TQApplication::restoreOverrideCursor();
 #endif
 	state = Inactive;
@@ -919,7 +919,7 @@ void TQWhatsThis::enterWhatsThisMode()
     TQWhatsThisPrivate::setUpWhatsThis();
     if ( wt->state == TQWhatsThisPrivate::Inactive ) {
 	wt->enterWhatsThisMode();
-#ifndef QT_NO_CURSOR
+#ifndef TQT_NO_CURSOR
 	TQApplication::setOverrideCursor( whatsThisCursor, FALSE );
 #endif
 	wt->state = TQWhatsThisPrivate::Waiting;
