@@ -40,7 +40,7 @@
 
 #include "ntqwidgetplugin.h"
 
-#ifndef QT_NO_WIDGETPLUGIN
+#ifndef TQT_NO_WIDGETPLUGIN
 #include "qwidgetinterface_p.h"
 #include "ntqobjectcleanuphandler.h"
 #include "ntqwidget.h"
@@ -726,4 +726,4 @@ TQString TQWidgetContainerPlugin::createCode( const TQString &, const TQString &
 
 #endif // QT_CONTAINER_CUSTOM_WIDGETS
 
-#endif //QT_NO_WIDGETPLUGIN
+#endif //TQT_NO_WIDGETPLUGIN
