@@ -506,6 +506,17 @@ TQString KCharsets::encodingForName( const TQString &descriptiveName )
     return name.left(right).stripWhiteSpace();
 }
 
+TQString KCharsets::descriptiveNameForEncoding( const TQString &encodingName )
+{
+    for ( const LanguageForEncoding* pos = language_for_encoding; pos->index; ++pos ) {
+        if ( encodingName == TQString::fromLatin1( pos->index )) {
+            const TQString description = i18n( language_names[ pos->data ] );
+            return i18n("Descriptive Encoding Name", "%1 ( %2 )"). arg ( description ). arg( encodingName );
+        }
+    }
+    return TQString::null;
+}
+
 TQStringList KCharsets::descriptiveEncodingNames()
 {
     // As we are sorting, we can directly read the array language_for_encoding
