@@ -97,7 +97,7 @@ static const char* const types[] = {"html", "html-bundle", "icon", "apps", "soun
 			      "data", "locale", "locale-bundle", "services", "mime",
 			      "servicetypes", "config", "exe",
 			      "wallpaper", "lib", "pixmap", "templates",
-			      "module", "qtplugins",
+			      "module", "tqtplugins",
 			      "xdgdata-apps", "xdgdata-dirs", "xdgconf-menu",
 			      "xdgdata-icon", "xdgdata-pixmap", "xdgconf-autostart",
 			      "kcfg", "emoticons", 0 };
@@ -1072,7 +1072,7 @@ TQString TDEStandardDirs::kde_default(const char *type) {
 	return "lib" KDELIBSUFF "/";
     if (!strcmp(type, "module"))
 	return "lib" KDELIBSUFF "/trinity/";
-    if (!strcmp(type, "qtplugins"))
+    if (!strcmp(type, "tqtplugins"))
         return "lib" KDELIBSUFF "/trinity/plugins";
     if (!strcmp(type, "xdgdata-apps"))
         return "applications/";
