@@ -32,38 +32,32 @@
 NotifierSettings::NotifierSettings()
 {
 	m_supportedMimetypes.append( "media/removable_unmounted" );
-	m_supportedMimetypes.append( "media/removable_unmounted_encrypted" );
-	m_supportedMimetypes.append( "media/removable_unmounted_decrypted" );
+	m_supportedMimetypes.append( "media/removable_encrypted_locked" );
+	m_supportedMimetypes.append( "media/removable_encrypted_unlocked" );
 	m_supportedMimetypes.append( "media/removable_mounted" );
-	m_supportedMimetypes.append( "media/removable_mounted_decrypted" );
 	m_supportedMimetypes.append( "media/camera_unmounted" );
 	m_supportedMimetypes.append( "media/camera_mounted" );
 	m_supportedMimetypes.append( "media/gphoto2camera" );
 	m_supportedMimetypes.append( "media/bluray_unmounted" );
-	m_supportedMimetypes.append( "media/bluray_unmounted_encrypted" );
-	m_supportedMimetypes.append( "media/bluray_unmounted_decrypted" );
+	m_supportedMimetypes.append( "media/bluray_encrypted_locked" );
+	m_supportedMimetypes.append( "media/bluray_encrypted_unlocked" );
 	m_supportedMimetypes.append( "media/bluray_mounted" );
-	m_supportedMimetypes.append( "media/bluray_mounted_decrypted" );
 	m_supportedMimetypes.append( "media/cdrom_unmounted" );
-	m_supportedMimetypes.append( "media/cdrom_unmounted_encrypted" );
-	m_supportedMimetypes.append( "media/cdrom_unmounted_decrypted" );
+	m_supportedMimetypes.append( "media/cdrom_encrypted_locked" );
+	m_supportedMimetypes.append( "media/cdrom_encrypted_unlocked" );
 	m_supportedMimetypes.append( "media/cdrom_mounted" );
-	m_supportedMimetypes.append( "media/cdrom_mounted_decrypted" );
 	m_supportedMimetypes.append( "media/cd-r_unmounted" );
-	m_supportedMimetypes.append( "media/cd-r_unmounted_encrypted" );
-	m_supportedMimetypes.append( "media/cd-r_unmounted_decrypted" );
+	m_supportedMimetypes.append( "media/cd-r_encrypted_locked" );
+	m_supportedMimetypes.append( "media/cd-r_encrypted_unlocked" );
 	m_supportedMimetypes.append( "media/cd-r_mounted" );
-	m_supportedMimetypes.append( "media/cd-r_mounted_decrypted" );
 	m_supportedMimetypes.append( "media/cd-rw_unmounted" );
-	m_supportedMimetypes.append( "media/cd-rw_unmounted_encrypted" );
-	m_supportedMimetypes.append( "media/cd-rw_unmounted_decrypted" );
+	m_supportedMimetypes.append( "media/cd-rw_encrypted_locked" );
+	m_supportedMimetypes.append( "media/cd-rw_encrypted_unlocked" );
 	m_supportedMimetypes.append( "media/cd-rw_mounted" );
-	m_supportedMimetypes.append( "media/cd-rw_mounted_decrypted" );
 	m_supportedMimetypes.append( "media/dvd_unmounted" );
-	m_supportedMimetypes.append( "media/dvd_unmounted_encrypted" );
-	m_supportedMimetypes.append( "media/dvd_unmounted_decrypted" );
+	m_supportedMimetypes.append( "media/dvd_encrypted_locked" );
+	m_supportedMimetypes.append( "media/dvd_encrypted_unlocked" );
 	m_supportedMimetypes.append( "media/dvd_mounted" );
-	m_supportedMimetypes.append( "media/dvd_mounted_decrypted" );
 	m_supportedMimetypes.append( "media/blankbluray" );
 	m_supportedMimetypes.append( "media/blankcd" );
 	m_supportedMimetypes.append( "media/blankdvd" );
