@@ -530,9 +530,9 @@ TQString KCMLirc::handbookDocPath() const
 {
  	int index = theKCMLircBase->tabWidget2->currentPageIndex();
  	if (index == 0)
-		return "kcmlirc/usage.html";
+		return "kcontrol/kcmlirc/usage.html";
 	else if (index == 1)
-		return "kcmlirc/extensions.html";
+		return "kcontrol/kcmlirc/extensions.html";
  	else
  		return TQString::null;
 }
