@@ -372,14 +372,14 @@ void ResourceCardDav::loadFinished() {
     if (loader->error()) {
         if (loader->errorNumber() == -401) {
             if (NULL != mPrefs) {
-                TQCString newpass;
+                TQString newpass;
                 if (KPasswordDialog::getPassword (newpass, TQString("<b>") + i18n("Remote authorization required") + TQString("</b><p>") + i18n("Please input the password for") + TQString(" ") + mPrefs->getusername(), NULL) != 1) {
                     log("load error: " + loader->errorString() );
                     if (addressBook() != NULL) addressBook()->error(TQString("[%1] ").arg(abs(loader->errorNumber())) + loader->errorString());
                 }
                 else {
                     // Set new password and try again
-                    mPrefs->setPassword(TQString(newpass));
+                    mPrefs->setPassword(newpass);
                     startLoading(mPrefs->getFullUrl());
                 }
             }
@@ -641,14 +641,14 @@ void ResourceCardDav::writingFinished() {
     if (mWriter->error() && (abs(mWriter->errorNumber()) != 207)) {
         if (mWriter->errorNumber() == -401) {
             if (NULL != mPrefs) {
-                TQCString newpass;
+                TQString newpass;
                 if (KPasswordDialog::getPassword (newpass, TQString("<b>") + i18n("Remote authorization required") + TQString("</b><p>") + i18n("Please input the password for") + TQString(" ") + mPrefs->getusername(), NULL) != 1) {
                     log("write error: " + mWriter->errorString());
                     if (addressBook() != NULL) addressBook()->error(TQString("[%1] ").arg(abs(mWriter->errorNumber())) + mWriter->errorString());
                 }
                 else {
                     // Set new password and try again
-                    mPrefs->setPassword(TQString(newpass));
+                    mPrefs->setPassword(newpass);
                     startWriting(mPrefs->getFullUrl());
                 }
             }
