@@ -22,6 +22,10 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 
 */
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include "kgreeter.h"
 #include "kconsole.h"
 #include "tdmconfig.h"
@@ -33,6 +37,14 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 #include "themer/tdmitem.h"
 #include "themer/tdmlabel.h"
 
+#include <dmctl.h>
+
+#ifdef WITH_TDEHWLIB
+#include <ksslcertificate.h>
+#include <tdehardwaredevices.h>
+#include <tdecryptographiccarddevice.h>
+#endif
+
 #include <tdeapplication.h>
 #include <tdelocale.h>
 #include <kstandarddirs.h>
@@ -92,6 +104,7 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 
 #include <X11/Xlib.h>
 
+
 #define FIFO_DIR "/tmp/tdesocket-global/tdm"
 #define FIFO_FILE "/tmp/tdesocket-global/tdm/tdmctl-%1"
 #define FIFO_SAK_FILE "/tmp/tdesocket-global/tdm/tdmctl-sak-%1"
@@ -185,6 +198,7 @@ KGreeter::KGreeter( bool framed )
   , prevValid( true )
   , needLoad( false )
   , themed( framed )
+  , showInfoMessages( true )
   , closingDown( false )
 {
 	stsFile = new KSimpleConfig( _stsFile );
@@ -234,6 +248,23 @@ KGreeter::~KGreeter()
 	delete stsFile;
 }
 
+void KGreeter::cryptographicCardWatcherSetup() {
+	cardLoginUser = TQString::null;
+
+#ifdef WITH_TDEHWLIB
+	// Initialize SmartCard readers
+	TDEGenericDevice *hwdevice;
+	TDEHardwareDevices *hwdevices = TDEGlobal::hardwareDevices();
+	TDEGenericHardwareList cardReaderList = hwdevices->listByDeviceClass(TDEGenericDeviceType::CryptographicCard);
+	for (hwdevice = cardReaderList.first(); hwdevice; hwdevice = cardReaderList.next()) {
+		TDECryptographicCardDevice* cdevice = static_cast<TDECryptographicCardDevice*>(hwdevice);
+		connect(cdevice, TQT_SIGNAL(certificateListAvailable(TDECryptographicCardDevice*)), this, TQT_SLOT(cryptographicCardInserted(TDECryptographicCardDevice*)));
+		connect(cdevice, TQT_SIGNAL(cardRemoved(TDECryptographicCardDevice*)), this, TQT_SLOT(cryptographicCardRemoved(TDECryptographicCardDevice*)));
+		cdevice->enableCardMonitoring(true);
+	}
+#endif
+}
+
 void KGreeter::done(int r) {
 	closingDown = true;
 	inherited::done(r);
@@ -414,9 +445,9 @@ class KCStringList : public TQValueList<TQCString> {
 	}
 };
 
-class UserList {
+class KGreeterUserList {
   public:
-	UserList( char **in );
+	KGreeterUserList( char **in );
 	bool hasUser( const char *str ) const { return users.contains( str ); }
 	bool hasGroup( gid_t gid ) const
 		{ return groups.find( gid ) != groups.end(); }
@@ -427,7 +458,7 @@ class UserList {
 	TQValueList<gid_t> groups;
 };
 
-UserList::UserList( char **in )
+KGreeterUserList::KGreeterUserList( char **in )
 {
 	struct group *grp;
 
@@ -462,7 +493,7 @@ KGreeter::insertUsers(int limit_users)
 			  default_pix.convertDepth( 32 ).smoothScale( ns, TQ_ScaleMin );
 	}
 	if (_showUsers == SHOW_ALL) {
-		UserList noUsers( _noUsers );
+		KGreeterUserList noUsers( _noUsers );
 		TQDict<int> dupes( 1000 );	// Potential crash risk with buffer overrun?
                 TQStringList toinsert;
                 int count = 0;
@@ -528,7 +559,7 @@ KGreeter::insertUsers(int limit_users)
                         insertUser( default_pix, *it, ps );
                 }
 	} else {
-		UserList users( _users );
+		KGreeterUserList users( _users );
 		if (users.hasGroups()) {
 			TQDict<int> dupes( 1000 );
 			for (setpwent(); (ps = getpwent()) != 0;) {
@@ -612,12 +643,13 @@ KGreeter::slotUserEntered()
 {
 	if (userView) {
 		TQListViewItem *item;
-		for (item = userView->firstChild(); item; item = item->nextSibling())
+		for (item = userView->firstChild(); item; item = item->nextSibling()) {
 			if (((UserListViewItem *)item)->login == curUser) {
 				userView->setSelected( item, true );
 				userView->ensureItemVisible( item );
 				goto oke;
 			}
+		}
 		userView->clearSelection();
 	}
   oke:
@@ -832,6 +864,106 @@ KGreeter::verifySetUser( const TQString &user )
 	slotUserEntered();
 }
 
+void KGreeter::cryptographicCardInserted(TDECryptographicCardDevice* cdevice) {
+#ifdef WITH_TDEHWLIB
+#ifndef HAVE_KRB5
+	// Don't enable card-based logins if Kerberos integration was disabled
+	return;
+#endif
+	// Make sure card logins are enabled before attempting one
+	KSimpleConfig *systemconfig = new KSimpleConfig( TQString::fromLatin1( KDE_CONFDIR "/ldap/ldapconfigrc" ));
+	systemconfig->setGroup(NULL);
+	bool enabled = systemconfig->readBoolEntry("EnablePKCS11Login", false);
+	delete systemconfig;
+	if (!enabled)
+	{
+		return;
+	}
+
+	TQString login_name = TQString::null;
+	X509CertificatePtrList certList = cdevice->cardX509Certificates();
+	if (certList.count() > 0) {
+		KSSLCertificate* card_cert = NULL;
+		card_cert = KSSLCertificate::fromX509(certList[0]);
+		TQStringList cert_subject_parts = TQStringList::split("/", card_cert->getSubject(), false);
+		for (TQStringList::Iterator it = cert_subject_parts.begin(); it != cert_subject_parts.end(); ++it ) {
+			TQString lcpart = (*it).lower();
+			if (lcpart.startsWith("cn=")) {
+				login_name = lcpart.right(lcpart.length() - strlen("cn="));
+			}
+		}
+		delete card_cert;
+	}
+
+	if (login_name != "") {
+		if (verify->cardLoginInProgress) {
+			return;
+		}
+		verify->cardLoginInProgress = true;
+		verify->cardLoginDevice = cdevice;
+
+		DM dm;
+		SessList sess;
+		bool vt_active = false;
+		bool user_active = false;
+		if (dm.localSessions(sess)) {
+			TQString user, loc;
+			for (SessList::ConstIterator it = sess.begin(); it != sess.end(); ++it) {
+				DM::sess2Str2(*it, user, loc);
+				if (user.startsWith(login_name + ": ")) {
+					// Found active session
+					user_active = true;
+				}
+				if ((*it).self) {
+					if ((*it).vt == dm.activeVT()) {
+						vt_active = true;
+					}
+				}
+			}
+		}
+
+		if (!user_active && vt_active) {
+			// Select the correct user
+			verify->setUser(login_name);
+			if (userView) {
+				userView->setEnabled(false);
+			}
+			verifySetUser(login_name);
+			verify->lockUserEntry(true);
+
+			// FIXME
+			// pam_pkcs11 is extremely chatty with no apparent way to disable the unwanted messages
+			verify->setInfoMessageDisplay(false);
+
+			// Set up password prompt
+			cardLoginUser = login_name;
+			verify->setPasswordPrompt(i18n("PIN:"));
+
+			// Bypass initial password prompt
+			verify->start();
+			verify->setPassword("");
+			verify->accept();
+		}
+	}
+#endif
+}
+
+void KGreeter::cryptographicCardRemoved(TDECryptographicCardDevice* cdevice) {
+#ifdef WITH_TDEHWLIB
+	cardLoginUser = TQString::null;
+	userView->setEnabled(false);
+	verify->lockUserEntry(false);
+        verify->requestAbort();
+        verify->setPasswordPrompt(TQString::null);
+
+	// Restore information message display settings
+        verify->setInfoMessageDisplay(showInfoMessages);
+
+	verify->cardLoginInProgress = false;
+	verify->cardLoginDevice = NULL;
+#endif
+}
+
 KStdGreeter::KStdGreeter()
   : KGreeter()
   , clock( 0 )
@@ -977,7 +1109,10 @@ KStdGreeter::KStdGreeter()
 
 	pluginSetup();
 
+        verify->setInfoMessageDisplay(showInfoMessages);
 	verify->start();
+
+	TQTimer::singleShot(0, this, SLOT(cryptographicCardWatcherSetup()));
 }
 
 void
@@ -1042,8 +1177,9 @@ KThemedGreeter::KThemedGreeter()
 	xauth_warning = themer->findNode( "xauth-warning" ); // tdm ext
 	pam_error = themer->findNode( "pam-error" );
 	timed_label = themer->findNode( "timed-label" );
-	if (pam_error && pam_error->isA( "KdmLabel" ))
+	if (pam_error && pam_error->isA( "KdmLabel" )) {
 		static_cast<KdmLabel*>(pam_error)->setText( i18n("Login Failed.") );
+	}
 
 	KdmItem *itm;
 	if ((itm = themer->findNode( "pam-message" ))) // done via msgboxes
@@ -1124,7 +1260,10 @@ KThemedGreeter::KThemedGreeter()
 
 	pluginSetup();
 
+	verify->setInfoMessageDisplay(showInfoMessages);
 	verify->start();
+
+	TQTimer::singleShot(0, this, SLOT(cryptographicCardWatcherSetup()));
 }
 
 bool
@@ -1202,6 +1341,12 @@ KThemedGreeter::updateStatus( bool fail, bool caps, int timedleft )
 			timed_label->hide( true );
 		}
 	}
+
+#ifdef WITH_TDEHWLIB
+	if (cardLoginUser != TQString::null) {
+		verify->setPasswordPrompt(i18n("PIN:"));
+	}
+#endif
 }
 
 void
