@@ -74,7 +74,9 @@ KWinbindGreeter::KWinbindGreeter( KGreeterPluginHandler *_handler,
 	ctx( _ctx ),
 	exp( -1 ),
 	pExp( -1 ),
-	running( false )
+	running( false ),
+	userEntryLocked(false),
+	suppressInfoMsg(false)
 {
 	KdmItem *user_entry = 0, *pw_entry = 0, *domain_entry = 0;
 	TQGridLayout *grid = 0;
@@ -89,8 +91,10 @@ KWinbindGreeter::KWinbindGreeter( KGreeterPluginHandler *_handler,
 		themer = 0;
 
 	if (!themer)
+	{
 		grid = new TQGridLayout( 0, 0, 10 );
 		layoutItem = TQT_TQLAYOUTITEM(grid);
+	}
 
 	domainLabel = loginLabel = passwdLabel = passwd1Label = passwd2Label = 0;
 	domainCombo = 0;
@@ -297,6 +301,11 @@ KWinbindGreeter::setUser( const TQString &user )
 	passwdEdit->selectAll();
 }
 
+void KWinbindGreeter::lockUserEntry( const bool lock ) {
+	userEntryLocked = lock;
+	loginEdit->setEnabled(!lock);
+}
+
 void // virtual
 KWinbindGreeter::setPassword( const TQString &pass )
 {
@@ -319,6 +328,27 @@ KWinbindGreeter::setEnabled( bool enable )
 		passwdEdit->setFocus();
 }
 
+void KWinbindGreeter::setInfoMessageDisplay(bool enable) {
+	suppressInfoMsg = !enable;
+}
+
+void KWinbindGreeter::setPasswordPrompt(const TQString &prompt) {
+#if 0
+	if (passwdLabel) {
+		if (prompt != TQString::null) {
+			passwdLabel->setText(prompt);
+		}
+		else {
+			passwdLabel->setText(passwordPrompt());
+		}
+		if (grid) {
+			grid->invalidate();
+			grid->activate();
+		}
+	}
+#endif
+}
+
 void // private
 KWinbindGreeter::returnData()
 {
@@ -328,16 +358,16 @@ KWinbindGreeter::returnData()
 		                          KGreeterPluginHandler::IsUser );
 		break;
 	case 1:
-		handler->gplugReturnText( passwdEdit->password(),
+		handler->gplugReturnText( passwdEdit->password().local8Bit(),
 		                          KGreeterPluginHandler::IsPassword |
 		                          KGreeterPluginHandler::IsSecret );
 		break;
 	case 2:
-		handler->gplugReturnText( passwd1Edit->password(),
+		handler->gplugReturnText( passwd1Edit->password().local8Bit(),
 		                          KGreeterPluginHandler::IsSecret );
 		break;
 	default: // case 3:
-		handler->gplugReturnText( passwd2Edit->password(),
+		handler->gplugReturnText( passwd2Edit->password().local8Bit(),
 		                          KGreeterPluginHandler::IsNewPassword |
 		                          KGreeterPluginHandler::IsSecret );
 		break;
@@ -348,8 +378,12 @@ bool // virtual
 KWinbindGreeter::textMessage( const char *text, bool err )
 {
 	if (!err &&
-	    TQString( text ).find( TQRegExp( "^Changing password for [^ ]+$" ) ) >= 0)
+	    TQString( text ).find( TQRegExp( "^Changing password for [^ ]+$" ) ) >= 0) {
 		return true;
+	}
+	if (!err && suppressInfoMsg) {
+		return true;
+	}
 	return false;
 }
 
@@ -524,12 +558,20 @@ KWinbindGreeter::clear()
 void
 KWinbindGreeter::setActive( bool enable )
 {
-	if (domainCombo)
+	if (domainCombo) {
 		domainCombo->setEnabled( enable );
-	if (loginEdit)
-		loginEdit->setEnabled( enable );
-	if (passwdEdit)
+	}
+	if (loginEdit) {
+		if (userEntryLocked) {
+			loginEdit->setEnabled( false );
+		}
+		else {
+			loginEdit->setEnabled( enable );
+		}
+	}
+	if (passwdEdit) {
 		passwdEdit->setEnabled( enable );
+	}
 }
 
 void
