@@ -1,4 +1,6 @@
-<!DOCTYPE TS><TS>
+<?xml version="1.0" encoding="utf-8"?>
+<!DOCTYPE TS>
+<TS language="ru">
 <context>
     <name>QAccel</name>
     <message>
@@ -59,19 +61,19 @@
     </message>
     <message>
         <source>Left</source>
-        <translation></translation>
+        <translation>Влево</translation>
     </message>
     <message>
         <source>Up</source>
-        <translation>Стрелка вверх</translation>
+        <translation>Вверх</translation>
     </message>
     <message>
         <source>Right</source>
-        <translation>Стрелка вправо</translation>
+        <translation>Вправо</translation>
     </message>
     <message>
         <source>Down</source>
-        <translation>Стрелка вниз</translation>
+        <translation>Вниз</translation>
     </message>
     <message>
         <source>PgUp</source>
@@ -115,59 +117,59 @@
     </message>
     <message>
         <source>Menu</source>
-        <translation></translation>
+        <translation>Меню</translation>
     </message>
     <message>
         <source>Help</source>
-        <translation></translation>
+        <translation>Справка</translation>
     </message>
     <message>
         <source>Back</source>
-        <translation></translation>
+        <translation>Назад</translation>
     </message>
     <message>
         <source>Forward</source>
-        <translation></translation>
+        <translation>Вперёд</translation>
     </message>
     <message>
         <source>Stop</source>
-        <translation></translation>
+        <translation>Стоп</translation>
     </message>
     <message>
         <source>Refresh</source>
-        <translation></translation>
+        <translation>Обновить</translation>
     </message>
     <message>
         <source>Volume Down</source>
-        <translation></translation>
+        <translation>Тише</translation>
     </message>
     <message>
         <source>Volume Mute</source>
-        <translation></translation>
+        <translation>Выключить звук</translation>
     </message>
     <message>
         <source>Volume Up</source>
-        <translation></translation>
+        <translation>Громче</translation>
     </message>
     <message>
         <source>Bass Boost</source>
-        <translation></translation>
+        <translation>Усиление басов</translation>
     </message>
     <message>
         <source>Bass Up</source>
-        <translation></translation>
+        <translation>Басы сильнее</translation>
     </message>
     <message>
         <source>Bass Down</source>
-        <translation></translation>
+        <translation>Басы слабее</translation>
     </message>
     <message>
         <source>Treble Up</source>
-        <translation></translation>
+        <translation>Высокие сильнее</translation>
     </message>
     <message>
         <source>Treble Down</source>
-        <translation></translation>
+        <translation>Высокие слабее</translation>
     </message>
     <message>
         <source>Media Play</source>
@@ -203,83 +205,83 @@
     </message>
     <message>
         <source>Open URL</source>
-        <translation></translation>
+        <translation>Открыть URL</translation>
     </message>
     <message>
         <source>Launch Mail</source>
-        <translation></translation>
+        <translation>Открыть почту</translation>
     </message>
     <message>
         <source>Launch Media</source>
-        <translation></translation>
+        <translation>Открыть медиа</translation>
     </message>
     <message>
         <source>Launch (0)</source>
-        <translation></translation>
+        <translation>Запуск (0)</translation>
     </message>
     <message>
         <source>Launch (1)</source>
-        <translation></translation>
+        <translation>Запуск (1)</translation>
     </message>
     <message>
         <source>Launch (2)</source>
-        <translation></translation>
+        <translation>Запуск (2)</translation>
     </message>
     <message>
         <source>Launch (3)</source>
-        <translation></translation>
+        <translation>Запуск (3)</translation>
     </message>
     <message>
         <source>Launch (4)</source>
-        <translation></translation>
+        <translation>Запуск (4)</translation>
     </message>
     <message>
         <source>Launch (5)</source>
-        <translation></translation>
+        <translation>Запуск (5)</translation>
     </message>
     <message>
         <source>Launch (6)</source>
-        <translation></translation>
+        <translation>Запуск (6)</translation>
     </message>
     <message>
         <source>Launch (7)</source>
-        <translation>Запустить (7)</translation>
+        <translation>Запуск (7)</translation>
     </message>
     <message>
         <source>Launch (8)</source>
-        <translation></translation>
+        <translation>Запуск (8)</translation>
     </message>
     <message>
         <source>Launch (9)</source>
-        <translation></translation>
+        <translation>Запуск (9)</translation>
     </message>
     <message>
         <source>Launch (A)</source>
-        <translation></translation>
+        <translation>Запуск (A)</translation>
     </message>
     <message>
         <source>Launch (B)</source>
-        <translation></translation>
+        <translation>Запуск (B)</translation>
     </message>
     <message>
         <source>Launch (C)</source>
-        <translation></translation>
+        <translation>Запуск (C)</translation>
     </message>
     <message>
         <source>Launch (D)</source>
-        <translation>Запустить (D)</translation>
+        <translation>Запуск (D)</translation>
     </message>
     <message>
         <source>Launch (E)</source>
-        <translation></translation>
+        <translation>Запуск (E)</translation>
     </message>
     <message>
         <source>Launch (F)</source>
-        <translation></translation>
+        <translation>Запуск (F)</translation>
     </message>
     <message>
         <source>Meta</source>
-        <translation></translation>
+        <translation>Мета</translation>
     </message>
     <message>
         <source>%1, %2 not defined</source>
@@ -347,7 +349,7 @@
     </message>
     <message>
         <source>Incompatible TQt Library Error</source>
-        <translation>Ошибка совместимости библиотеки Qt</translation>
+        <translation>Ошибка совместимости библиотеки TQt</translation>
     </message>
 </context>
 <context>
@@ -474,7 +476,7 @@
     </message>
     <message>
         <source> to All</source>
-        <translation>для всех</translation>
+        <translation> для всех</translation>
     </message>
     <message>
         <source>Yes</source>
@@ -544,11 +546,11 @@
     </message>
     <message>
         <source>Could not read from the file</source>
-        <translation>Не удается прочитать из файла</translation>
+        <translation>Не удаётся прочитать из файла</translation>
     </message>
     <message>
         <source>Could not write to the file</source>
-        <translation>Не удается записать в файл</translation>
+        <translation>Не удаётся записать в файл</translation>
     </message>
     <message>
         <source>Permission denied</source>
@@ -1018,47 +1020,47 @@ Check path and filename.</source>
     </message>
     <message>
         <source>SpacingModifiers</source>
-        <translation></translation>
+        <translation>Модификации пробела</translation>
     </message>
     <message>
         <source>CombiningMarks</source>
-        <translation></translation>
+        <translation>Комбинируемые знаки</translation>
     </message>
     <message>
         <source>Tagalog</source>
-        <translation></translation>
+        <translation>Тагальский</translation>
     </message>
     <message>
         <source>Hanunoo</source>
-        <translation></translation>
+        <translation>Хануну</translation>
     </message>
     <message>
         <source>Buhid</source>
-        <translation></translation>
+        <translation>Бухид</translation>
     </message>
     <message>
         <source>Tagbanwa</source>
-        <translation></translation>
+        <translation>Тагбанва</translation>
     </message>
     <message>
         <source>Katakana Half-Width Forms</source>
-        <translation>Katakana c половинными формами</translation>
+        <translation>Катакана c половинными формами</translation>
     </message>
     <message>
         <source>Han (Japanese)</source>
-        <translation>Han (Японский)</translation>
+        <translation>Хан (японский)</translation>
     </message>
     <message>
         <source>Han (Simplified Chinese)</source>
-        <translation>Han (упрощенный Китайский)</translation>
+        <translation>Хан (упрощенный китайский)</translation>
     </message>
     <message>
         <source>Han (Traditional Chinese)</source>
-        <translation>Han (традиционный Китайский)</translation>
+        <translation>Хан (традиционный китайский)</translation>
     </message>
     <message>
         <source>Han (Korean)</source>
-        <translation>Han (Корейский)</translation>
+        <translation>Хан (корейский)</translation>
     </message>
     <message>
         <source>Unknown Script</source>
@@ -1338,7 +1340,7 @@ Check path and filename.</source>
     </message>
     <message>
         <source>Select All</source>
-        <translation>Выделить все</translation>
+        <translation>Выделить всё</translation>
     </message>
 </context>
 <context>
@@ -1563,7 +1565,7 @@ to
     </message>
     <message>
         <source>Print all</source>
-        <translation>Печатать все</translation>
+        <translation>Печатать всё</translation>
     </message>
     <message>
         <source>Print range</source>
@@ -1753,7 +1755,7 @@ to
     </message>
     <message>
         <source>bad char class syntax</source>
-        <translation>ошибочный синтаксис класса  символа</translation>
+        <translation>ошибочный синтаксис класса символа</translation>
     </message>
     <message>
         <source>bad lookahead syntax</source>
@@ -1874,7 +1876,7 @@ to
     </message>
     <message>
         <source>Select All</source>
-        <translation>Выделить все</translation>
+        <translation>Выделить всё</translation>
     </message>
 </context>
 <context>
@@ -2114,7 +2116,7 @@ to
     </message>
     <message>
         <source>tag mismatch</source>
-        <translation>несоответствие тегов </translation>
+        <translation>несоответствие тегов</translation>
     </message>
     <message>
         <source>error occurred while parsing content</source>
